########################################################################################
########## A global dataset of pandemic- and epidemic-prone disease outbreaks ########## 
########################################################################################

### Packages ###
require("stringr")
require("tidyverse")
require("stringr")
require("rvest")
require("renv")
require("clock")
require("lubridate")
require("readxl")
require("plyr")
require("clock")

## To load in the current session and also write the infrastructure necessary to 
## ensure the project is auto-loaded for newly-launched R sessions 
renv::activate()

## Default Language: English
Sys.setenv(LANG = "en")
Sys.setlocale("LC_TIME", "English")

############################### Information on outbreaks ############################### 

### Database on disease outbreaks from the WHO web https://www.who.int/emergencies/disease-outbreak-news ###
# empty dataset
data <- data.frame("Outbreak" = NA,
                   "Date" = NA,
                   "Year" = NA,
                   "Month" = NA,
                   "Day" = NA,
                   "Description" = NA,
                   "Link" = NA)

## Reading the web page ##
# Running the following lines takes many hours to compute
# alternatively, the final data can be found in the project file
# base::load("DON.RData")
# This data contain information until the 31st of March 2022

for(page in 1:135){ # until 135 because this is the number of pages in the WHO. This has to be accordingly updated. 
  
  webpage <- read_html(paste0("https://www.who.int/emergencies/disease-outbreak-news/", page))
  
 # Extracting the link from each DON
  newslink <- webpage %>% 
    html_nodes("a.sf-list-vertical__item") %>%
    html_attr("href")
  
  for(news in 1:length(newslink)){
    data[(page-1)*20+news, "Link"] <- newslink[news]
    
    # Extracting the title from each DON
    data[(page-1)*20+news, "Outbreak"] <- read_html(newslink[news]) %>%
      html_nodes("ul.sf-breadscrumb.breadcrumb") %>%
      html_elements("li.active") %>%
      html_text2()  
    
    # Extracting the information on date from each DON
    data[(page-1)*20+news, "Date"] <- read_html(newslink[news]) %>%
      html_nodes("div.sf-item-header-wrapper") %>%
      html_elements("span.timestamp") %>%
      html_text2()  
    
    # Extracting the Description from each DON
    data[(page-1)*20+news, "Description"] <- read_html(newslink[news]) %>%
      html_nodes("article.sf-detail-body-wrapper") %>%
      html_text2()
  }
}   

data <- data %>% 
  mutate(Date = as.Date(Date, format = "%d %b %Y")) %>%
  mutate(Year = get_year(Date), 
         Month = get_month(Date), 
         Day = get_day(Date))

save(data, file = "DON.RData") ## Saving all DON's

# 2019 is not complete #
# We have already collected for the first version of the paper, so we extract from there
# Unfortunately, the the previous website is not anymore available: https://www.who.int/csr/don/archive/year/2019
data2019 <- read_excel("DONs2019.xlsx")

data2019 <- data2019 %>% 
  mutate(Date = as.Date(Date, format = "%d %b %Y")) %>%
  mutate(Year = get_year(Date), 
         Month = get_month(Date), 
         Day = get_day(Date))

### Extract all years except 2019 from data
dataSub <- data %>% 
  filter(Year != 2019) # 2659-2602 = 57

save(dataSub, file = "dataSub.RData")

## All DONs together ##
DONsdf <- bind_rows(dataSub, data2019) %>% # 2721 
  arrange(desc(Year), desc(Month), desc(Day), desc(Link)) %>% # Ordering data by date
  rowid_to_column() %>%
  mutate(ID = paste0("DON", str_pad(rev(rowid), 4, pad = "0"))) %>% # ID to identify each DON. Assigning an ID to each report. Oldest one is DON0001
  select(-rowid)

DONsRaw <- DONsdf[, c("ID", "Description", "Date", "Link")]

save(DONsRaw, file = "DONsRaw.RData")

### Disease names ###
## Setting homogeneous names ##
# International Classification of Diseases ##
icd <- read.csv(file = "icd1011.csv", sep = ";", encoding = "UTF-8")

# Extracting disease name #
DONsdf2 <- DONsdf %>%
  mutate(Disease = case_when(Year >= 2013 ~  str_split(Outbreak, " – | - | ｰ |- |, | in | – | – | – ", simplify = TRUE)[, 1],  
                             TRUE ~ str_split(Outbreak, " in ", simplify = TRUE)[, 1])) %>%
  mutate(Disease = case_when(Year <= 2002 ~  str_split(Disease, " - ", simplify = TRUE)[, 2], 
                             TRUE ~ Disease)) 
DONsdf2 <- DONsdf2 %>%
  mutate(Disease = case_when(Disease == "" & Year <= 2002 ~  str_split(Outbreak, "- ", simplify = TRUE)[, 2], 
                             TRUE ~ Disease))
DONsdf2 <- DONsdf2 %>%
  mutate(Disease = case_when(Disease == "" & Year <= 2002 ~  str_split(Outbreak, " -", simplify = TRUE)[, 2], 
                             TRUE ~ Disease)) 

DONsdf3 <- DONsdf2 %>%
  mutate(icd104n = case_when(grepl(Disease, pattern = "aemorrhagic fever") ~ "Unspecified viral haemorrhagic fever",
                             grepl(Disease, pattern = "Eboal haemorrhagic fever") ~ "Ebola virus disease",
                             grepl(Disease, pattern = "[C|c]holera") ~ "Classical cholera", 
                             grepl(Disease, pattern = "[T|t]yphoid") ~ "Typhoid fever",
                             grepl(Disease, pattern = "[S|s]almon") ~ "Salmonella infection, unspecified",
                             grepl(Disease, pattern = "[S|s]higell") ~ "Shigellosis due to Shigella flexneri",
                             grepl(Disease, pattern = "[S|s]tap") ~ "Foodborne staphylococcal intoxication",
                             grepl(Disease, pattern = "[B|b]otul") ~ "Botulism",
                             grepl(Disease, pattern = "food-borne") ~ "Bacterial foodborne intoxication, unspecified",
                             grepl(Disease, pattern = "diarrhoea") ~ "Other and unspecified gastroenteritis and colitis of infectious origin",
                             grepl(Disease, pattern = "repatriation") ~ "Other and unspecified gastroenteritis and colitis of infectious origin",
                             grepl(Disease, pattern = "[T|t]uberc") ~ "Respiratory tuberculosis unspecified, confirmed bacteriologically and histologically",
                             grepl(Disease, pattern = "[P|p]lag") ~ "Plague, unspecified",
                             grepl(Disease, pattern = "[B|b]ubon") ~ "Bubonic plague",
                             grepl(Disease, pattern = "[T|t]ulare") ~ "Tularaemia, unspecified",
                             grepl(Disease, pattern = "[A|a]nthrax") ~ "Anthrax, unspecified",
                             grepl(Disease, pattern = "[L|l]epto") ~ "Leptospirosis, unspecified",
                             grepl(Disease, pattern = "[L|l]iste") ~ "Listeriosis, unspecified",
                             grepl(Disease, pattern = "[D|d]iph") ~ "Diphtheria, unspecified",
                             grepl(Disease, pattern = "[P|p]ertus") ~ "Whooping cough due to Bordetella pertussis",
                             grepl(Disease, pattern = "[M|m]eningi") ~ "Viral meningitis, unspecified",
                             grepl(Disease, pattern = "[M|m]eningo") ~ "Meningococcal meningitis",
                             grepl(Disease, pattern = "[S|s]treptoc") ~ "Streptococcal sepsis, unspecified",
                             grepl(Disease, pattern = "[L|l]egio") ~ "Legionnaires disease",
                             grepl(Disease, pattern = "[L|l]ouse") ~ "Epidemic louse-borne typhus fever due to Rickettsia prowazekii",
                             grepl(Disease, pattern = "[P|p]olio") ~ "Acute poliomyelitis, unspecified",
                             grepl(Disease, pattern = "[E|e]ncep") ~ "Mosquito-borne viral encephalitis, unspecified",
                             grepl(Disease, pattern = "[J|j]ak") ~ "Creutzfeldt-Jakob disease",
                             grepl(Disease, pattern = "[B|b]ovi") ~ "Creutzfeldt-Jakob disease",
                             grepl(Disease, pattern = "[V|v]enez") ~ "Venezuelan equine fever",
                             grepl(Disease, pattern = "[R|r]abie") ~ "Rabies, unspecified",
                             grepl(Disease, pattern = "[C|c]hik") ~ "Chikungunya virus disease",
                             grepl(Disease, pattern = "nyong") ~ "O'nyong-nyong fever",
                             grepl(Disease, pattern = "[N|n]ile") ~ "West Nile virus infection",
                             grepl(Disease, pattern = "[R|r]ift") ~ "Rift Valley fever",
                             grepl(Disease, pattern = "[Z|z]ika") ~ "Zika virus disease",
                             grepl(Disease, pattern = "[M|m]ayaro") ~ "Other specified mosquito-borne viral fevers",
                             grepl(Disease, pattern = "[O|o]ropo") ~ "Oropouche virus disease",
                             grepl(Disease, pattern = "[S|s]ylvatic") ~ "Sylvatic yellow fever",
                             grepl(Disease, pattern = "[Y|y]ellow") ~ "Yellow fever, unspecified",
                             grepl(Disease, pattern = "[L|l]assa") ~ "Lassa fever",
                             grepl(Disease, pattern = "[A|a]renav") ~ "Arenaviral haemorrhagic fever, unspecified",
                             grepl(Disease, pattern = "[D|d]engue") ~ "Dengue, unspecified",
                             grepl(Disease, pattern = "[C|c]rimean") ~ "Crimean-Congo haemorrhagic fever",
                             grepl(Disease, pattern = "[M|m]arburg") ~ "Marburg virus disease",
                             grepl(Disease, pattern = "[E|e]bola") ~ "Ebola virus disease",
                             grepl(Disease, pattern = "renal") ~ "Haemorrhagic fever with renal syndrome",
                             grepl(Disease, pattern = "[S|s]eoul") ~ "Haemorrhagic fever with renal syndrome",
                             grepl(Disease, pattern = "[A|a]cute haemo") ~ "Unspecified viral haemorrhagic fever",
                             grepl(Disease, pattern = "[M|m]onkey") ~ "Monkeypox",
                             grepl(Disease, pattern = "[M|m]easles") ~ "Measles",
                             grepl(Disease, pattern = "hand, foot and mouth") ~ "Enteroviral vesicular stomatitis with exanthem",
                             grepl(Disease, pattern = "[H|h]epatitis A") ~ "Acute hepatitis A",
                             grepl(Disease, pattern = "[H|h]epatitis E") ~ "Acute hepatitis E",
                             grepl(Disease, pattern = "HIV") ~ "Unspecified human immunodeficiency virus [HIV] disease",
                             grepl(Disease, pattern = "[H|h]anta") ~ "Hantavirus (cardio-)pulmonary syndrome",
                             grepl(Disease, pattern = "[B|b]uffalopox") ~ "Other specified viral diseases",
                             grepl(Disease, pattern = "[E|e]nterovirus") ~ "Enterovirus infection, unspecified site",
                             grepl(Outbreak, pattern = "is not SARS") ~ "Coronavirus infection, unspecified site",
                             grepl(Disease, pattern = "[N|n]ipa") ~ "Other viral infections of unspecified site",
                             grepl(Disease, pattern = "[N|n]eurolo") ~ "Other viral infections of unspecified site",
                             grepl(Disease, pattern = "[C|c]occidio") ~ "Coccidioidomycosis, unspecified",
                             grepl(Disease, pattern = "[M|m]alaria") ~ "Unspecified malaria",
                             grepl(Disease, pattern = "[L|l]eish") ~ "Leishmaniasis, unspecified",
                             grepl(Disease, pattern = "[D|d]racu") ~ "Dracunculiasis",
                             grepl(Disease, pattern = "[C|c]oli") ~ "Escherichia coli [E. coli] as the cause of diseases classified to other chapters",
                             grepl(Disease, pattern = "EHEC") ~ "Escherichia coli [E. coli] as the cause of diseases classified to other chapters",
                             grepl(Disease, pattern = "[I|i]nfluenza") ~ "Influenza due to identified zoonotic or pandemic influenza virus",
                             grepl(Disease, pattern = "[P|p]neumonia") ~ "Viral pneumonia, unspecified",
                             grepl(Disease, pattern = "[M|m]iddle [E|e]ast") ~ "Middle East respiratory syndrome coronavirus [MERS-CoV]",
                             grepl(Disease, pattern = "[A|a]cute [R|r]espira") ~ "Severe acute respiratory syndrome [SARS]",
                             grepl(Outbreak, pattern = "hepatitis of unknown") ~ "Acute viral hepatitis, unspecified",
                             grepl(Disease, pattern = "SARS-CoV-2") ~ "COVID-19",
                             grepl(Disease, pattern = "Novel Coronavirus") & Year == 2020 ~ "COVID-19",
                             grepl(Disease, pattern = "Undiagnosed Febrile Illness") ~ "Ebola virus disease",
                             grepl(Disease, pattern = "[P|p]seudomonas aeruginosa") ~ "Pseudomonas (aeruginosa) as the cause of diseases classified to other chapters",
                             grepl(Disease, pattern = "[G|g]onococcal") ~ "Meningococcal meningitis",
                             grepl(Outbreak, pattern = "Acute neurological syndrome in Bangladesh") ~ "Other viral infections of unspecified site", 
                             grepl(Outbreak, pattern = "Ebola haemorrhagic fever in Gabon") ~ "Ebola virus disease", 
                             grepl(Disease, pattern = "SARS-CoV-2") ~ "COVID-19",
                             grepl(Disease, pattern = "smallpox vaccine") ~ "Accidental poisoning by and exposure to other and unspecified drugs, medicaments and biological substances",
                             grepl(Disease, pattern = "Acute febrile illness") ~ "Leptospirosis, unspecified",
                             grepl(Outbreak, pattern = "SARS") & Year < 2020 ~ "Severe acute respiratory syndrome [SARS]",
                             grepl(Disease, pattern = "Diarrhoeal diseases") ~ "Other and unspecified gastroenteritis and colitis of infectious origin",
                             grepl(Disease, pattern = "[D|d]ysentery") ~ "Shigellosis due to Shigella flexneri",
                             grepl(Disease, pattern = "Elizabethkingia") ~ "Other and unspecified infectious diseases",
                             grepl(Disease, pattern = "myocarditis") ~ "Other and unspecified infectious diseases",
                             grepl(Disease, pattern = "food poiso") ~ "Other and unspecified infectious diseases",
                             grepl(Disease, pattern = "Guillain") ~ "Guillain-Barré syndrome",
                             grepl(Disease, pattern = "Health conditions for travellers") ~ "Yellow fever, unspecified",
                             grepl(Disease, pattern = "Health situation") ~ "Classical cholera",
                             grepl(Disease, pattern = "Hendra-like virus") ~ "Other viral infections of unspecified site",
                             grepl(Disease, pattern = "Hurricane Mitch, Update 8") ~ "Classical cholera",
                             grepl(Disease, pattern = "Hurricane Mitch, Update 6") ~ "Dengue, unspecified",
                             grepl(Disease, pattern = "Hurricane Mitch, Update 5") ~ "Unspecified malaria",
                             grepl(Disease, pattern = "Hurricane Mitch, Update 4") ~ "Leptospirosis, unspecified",
                             grepl(Disease, pattern = "solation of H5 viruses") ~ "Influenza due to identified zoonotic or pandemic influenza virus",
                             grepl(Disease, pattern = "Lead intoxication") ~ "Exposure to other specified factors",
                             grepl(Disease, pattern = "Health situation") ~ "Classical cholera",
                             grepl(Disease, pattern = "icrocephaly") ~ "Microcephaly",
                             grepl(Disease, pattern = "lead poisoning") ~ "Exposure to other specified factors",
                             grepl(Disease, pattern = "Novel coronavirus infection") ~ "Middle East respiratory syndrome coronavirus [MERS-CoV]",
                             grepl(Disease, pattern = "haemolytic uraemic") ~ "Escherichia coli [E. coli] as the cause of diseases classified to other chapters",
                             grepl(Disease, pattern = "Outbreak of illness") ~ "Other and unspecified infectious diseases",
                             grepl(Disease, pattern = "\\(H1") ~ "Influenza due to identified zoonotic or pandemic influenza virus",
                             grepl(Disease, pattern = "Seychelles") ~ "Plague, unspecified",
                             grepl(Disease, pattern = "Unexplained cluster of deaths") ~ "Other and unspecified infectious diseases",
                             grepl(Disease, pattern = "Undiagnosed illness") ~ "Other and unspecified infectious diseases",
                             grepl(Disease, pattern = "Suspected Acute Haemorrhagic Fever") ~ "Unspecified viral haemorrhagic fever",
                             grepl(Disease, pattern = "[S|s]wine") ~ "Influenza due to identified zoonotic or pandemic influenza virus",
                             grepl(Disease, pattern = "[U|u]nknown") ~ "Other and unspecified infectious diseases",
                             grepl(Disease, pattern = "[M|m]elamine") ~ "Accidental poisoning by and exposure to other and unspecified drugs, medicaments and biological substances",
                             grepl(Disease, pattern = "Update 88 – New cases reported") ~ "Severe acute respiratory syndrome [SARS]",
                             grepl(Disease, pattern = "Update 74 - Global decline") ~ "Severe acute respiratory syndrome [SARS]",
                             grepl(Disease, pattern = "Update 73 - No new deaths") ~ "Severe acute respiratory syndrome [SARS]",
                             grepl(Disease, pattern = "Update 72 - Situation") ~ "Severe acute respiratory syndrome [SARS]",
                             grepl(Disease, pattern = "Update 71 - Status") ~ "Severe acute respiratory syndrome [SARS]",
                             grepl(Disease, pattern = "Update 69 - Situation") ~ "Severe acute respiratory syndrome [SARS]",
                             grepl(Disease, pattern = "Update 65 - Situation") ~ "Severe acute respiratory syndrome [SARS]",
                             grepl(Disease, pattern = "Update 62 - More") ~ "Severe acute respiratory syndrome [SARS]",
                             grepl(Outbreak, pattern = "Yellow fever - Update 6") ~ "Yellow fever, unspecified", 
                             grepl(Outbreak, pattern = "Yellow fever in Cõte d'Ivoire - Update 3") ~ "Yellow fever, unspecified", 
                             grepl(Outbreak, pattern = "Ebola haemorrhagic fever in Uganda") ~ "Ebola virus disease", 
                             grepl(Outbreak, pattern = "Single isolation of H5N1 influenza virus") ~ "Influenza due to identified zoonotic or pandemic influenza virus",
                             grepl(Outbreak, pattern = "Yellow fever in Brazil") ~ "Yellow fever, unspecified", 
                             grepl(Outbreak, pattern = "Unidentified disease") ~ "Other and unspecified infectious diseases"))

## DONs related to multiple diseases
# Some news report more than one outbreak diarrhoeal and cholera ##
DONsdf4 <- DONsdf3 %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Watery Diarrhoea with V. cholerae positive cases in Viet Nam$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1999 - Diarrhoeal disease/cholera in Congo$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1998 - Cholera/acute diarrhoea in Somalia$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1998 - Cholera/diarrhoea outbreak in Liberia$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1996 - Influenza and malaria in Ghana$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^EHEC outbreak: Increase in cases in Germany$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1999 - Janpanese Encephalitis and Hendra-like Viurs in Malaysia$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Chikungunya and Dengue in the south west Indian Ocean$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1996 - Rwanda repatriation movement$"), 3, 1)) %>%
  uncount(repeated_row)
  
DONsdf4[grepl(DONsdf4$Outbreak, pattern = "^Severe Acute Watery Diarrhoea with V. cholerae positive cases in Viet Nam$"), "icd104n"] <- c("Classical cholera", "Other and unspecified gastroenteritis and colitis of infectious origin")
DONsdf4[grepl(DONsdf4$Outbreak, pattern = "^1999 - Diarrhoeal disease/cholera in Congo$"), "icd104n"] <- c("Classical cholera", "Other and unspecified gastroenteritis and colitis of infectious origin")
DONsdf4[grepl(DONsdf4$Outbreak, pattern = "^1998 - Cholera/acute diarrhoea in Somalia$"), "icd104n"] <- c("Classical cholera", "Other and unspecified gastroenteritis and colitis of infectious origin")
DONsdf4[grepl(DONsdf4$Outbreak, pattern = "^1998 - Cholera/diarrhoea outbreak in Liberia$"), "icd104n"] <- c("Classical cholera", "Other and unspecified gastroenteritis and colitis of infectious origin")
DONsdf4[grepl(DONsdf4$Outbreak, pattern = "^1996 - Influenza and malaria in Ghana$"), "icd104n"] <- c("Unspecified malaria", "Influenza due to identified zoonotic or pandemic influenza virus")
DONsdf4[grepl(DONsdf4$Outbreak, pattern = "^EHEC outbreak: Increase in cases in Germany$"), "icd104n"] <- c("Escherichia coli [E. coli] as the cause of diseases classified to other chapters", "Haemolytic-uraemic syndrome")
DONsdf4[grepl(DONsdf4$Outbreak, pattern = "^1999 - Janpanese Encephalitis and Hendra-like Viurs in Malaysia$"), "icd104n"] <- c("Japanese encephalitis", "Other viral infections of unspecified site")
DONsdf4[grepl(DONsdf4$Outbreak, pattern = "^Chikungunya and Dengue in the south west Indian Ocean$"), "icd104n"] <- c("Dengue, unspecified", "Chikungunya virus disease")
DONsdf4[grepl(DONsdf4$Outbreak, pattern = "^1996 - Rwanda repatriation movement$"), "icd104n"] <- c("Classical cholera", "Other and unspecified gastroenteritis and colitis of infectious origin", "Measles") 

## Other remaining cases to classify
DONsdf4[grepl(DONsdf4$Outbreak, pattern = "^Japanese Encephalitis \\(JE\\) in India$"), "icd104n"] <- "Japanese encephalitis"
DONsdf4[grepl(DONsdf4$Disease, pattern = "^Japanese encephalitis$"), "icd104n"] <- "Japanese encephalitis" # Misprint from source
DONsdf4[grepl(DONsdf4$Disease, pattern = "^St. Louis [E|e]ncephalitis$"), "icd104n"] <- "St Louis encephalitis"
DONsdf4[grepl(DONsdf4$Disease, pattern = "Bubonic"), "icd104n"] <- "Bubonic plague"
DONsdf4[grepl(DONsdf4$Disease, pattern = "[V|v]enez"), "icd104n"] <- "Venezuelan equine fever"
DONsdf4[grepl(DONsdf4$Outbreak, pattern = "^Gonococcal infection – United Kingdom$"), "icd104n"] <- "Gonococcal infection, unspecified"

DONsdf5 <- DONsdf4 %>% 
  select(-Disease) %>% 
  join(icd, type = "left", by = "icd104n", match = "all")

# All DONs with ICD-10 information
save(DONsdf5, file = "DONsICD10.RData")

# Only DONs related to diseases, i.e. deleting those with information on events, rules, recommendations, etc.
DONsdf6 <- DONsdf5 %>%
  drop_na(icd10c)

# iso codes #
iso <- read.csv(file = "isocodes.csv", sep = ";", encoding = "UTF-8")

# Extracting country name #
DONsdf7 <- DONsdf6 %>%
  mutate(Country = case_when(Year >= 2013 ~  str_split(Outbreak, " – | - | ｰ |- |, | in | – | – | – | - ", simplify = TRUE)[, 2],  
                             TRUE ~ str_split(Outbreak, " in ", simplify = TRUE)[, 2]))

# Country names as in ISO 
DONsdf8 <- DONsdf7 %>%
  mutate(Country = case_when(grepl(Country, pattern = "Zimbabwe") ~ "Zimbabwe",
                             grepl(Country, pattern = "Zambia") ~ "Zambia",
                             grepl(Country, pattern = "Zaire") ~ "Congo Democratic Republic of the", # Zaire is known from 1997 as Democratic Republic of the Congo
                             grepl(Country, pattern = "Yemen") ~ "Yemen",
                             grepl(Country, pattern = "Viet") ~ "Viet Nam",
                             grepl(Country, pattern = "Venezuela") ~ "Venezuela (Bolivarian Republic of)",
                             grepl(Country, pattern = "Uruguay") ~ "Uruguay",
                             grepl(Country, pattern = "United Arab") ~ "United Arab Emirates",
                             grepl(Country, pattern = "United States") ~ "United States of America",
                             grepl(Country, pattern = "Tanzania") ~ "Tanzania United Republic of",
                             grepl(Country, pattern = "United Kingdom") ~ "United Kingdom of Great Britain and Northern Ireland",
                             grepl(Country, pattern = "^UK") ~ "United Kingdom of Great Britain and Northern Ireland",
                             grepl(Country, pattern = "Ukraine") ~ "Ukraine",
                             grepl(Country, pattern = "Uganda") ~ "Uganda",
                             grepl(Country, pattern = "Turkey") ~ "Turkey",
                             grepl(Country, pattern = "Trinidad and Tobago") ~ "Trinidad and Tobago",
                             grepl(Country, pattern = "Toronto") ~ "Canada",
                             grepl(Country, pattern = "Togo") ~ "Togo",
                             grepl(Country, pattern = "Timor") ~ "Timor-Leste",
                             grepl(Country, pattern = "Tunisia") ~ "Tunisia",
                             grepl(Country, pattern = "Syrian") ~ "Syrian Arab Republic",
                             grepl(Country, pattern = "Congo") & !grepl(Country, pattern = "Democratic") ~ "Congo",
                             grepl(Country, pattern = "pines") ~ "Philippines",
                             grepl(Country, pattern = "Netherlands") ~ "Netherlands",
                             grepl(Country, pattern = "Arabia") ~ "Saudi Arabia",
                             grepl(Country, pattern = "Saint Martin") ~ "Saint Martin (French part)",
                             grepl(Country, pattern = "Micronesia") ~ "Micronesia (Federated States of)",
                             grepl(Country, pattern = "Democratic Republic of the Congo") ~ "Congo Democratic Republic of the", # Zaire is known from 1997 as Democratic Republic of the Congo
                             grepl(Country, pattern = "Comoros") ~ "Comoros",
                             grepl(Country, pattern = "Central African") ~ "Central African Republic",
                             grepl(Country, pattern = "Thailand") ~ "Thailand",
                             grepl(Country, pattern = "Tajikistan") ~ "Tajikistan",
                             grepl(Country, pattern = "Taiwan") ~ "Taiwan Province of China",
                             grepl(Country, pattern = "Tadjikistan") ~ "Tajikistan",
                             grepl(Country, pattern = "Sweden") ~ "Sweden",
                             grepl(Country, pattern = "Suriname") ~ "Suriname",
                             grepl(Country, pattern = "Sudan") & !grepl(Country, pattern = "South") ~ "Sudan",
                             grepl(Country, pattern = "Lanka") ~ "Sri Lanka",
                             grepl(Country, pattern = "Spain") ~ "Spain",
                             grepl(Country, pattern = "Sweden") ~ "Sweden",
                             grepl(Country, pattern = "China") & !grepl(Country, pattern = "Taiwan") & !grepl(Country, pattern = "Hong Kong") ~ "China",
                             grepl(Country, pattern = "outh Sudan") ~ "South Sudan",
                             grepl(Country, pattern = "South Africa") ~ "South Africa",
                             grepl(Country, pattern = "Somalia") ~ "Somalia",
                             grepl(Country, pattern = "Singapore") ~ "Singapore",
                             grepl(Country, pattern = "Sierra Leone") ~ "Sierra Leone",
                             grepl(Country, pattern = "Senegal") ~ "Senegal",
                             grepl(Country, pattern = "Saint Vincent and the") ~ "Saint Vincent and the Grenadines",
                             grepl(Country, pattern = "Saint Lucia") ~ "Saint Lucia",
                             grepl(Country, pattern = "Rwanda") ~ "Rwanda",
                             grepl(Country, pattern = "Russia") ~ "Russian Federation",
                             grepl(Country, pattern = "Romania") ~ "Romania",
                             grepl(Country, pattern = "Réunion") ~ "Réunion",
                             grepl(Country, pattern = "Panama") ~ "Panama",
                             grepl(Country, pattern = "Korea") & grepl(Country, pattern = "Republic") ~ "Korea Republic of",
                             grepl(Country, pattern = "Ghana") ~ "Ghana",
                             grepl(Country, pattern = "Qatar") ~ "Qatar",
                             grepl(Country, pattern = "Peru") ~ "Peru",
                             grepl(Country, pattern = "France") ~ "France",
                             grepl(Country, pattern = "Paraguay") ~ "Paraguay",
                             grepl(Country, pattern = "Papua New Guinea") ~ "Papua New Guinea",
                             grepl(Country, pattern = "Pakistan") ~ "Pakistan",
                             grepl(Country, pattern = "Oman") ~ "Oman",
                             grepl(Country, pattern = "Norway") ~ "Norway",
                             grepl(Country, pattern = "Mozambique") ~ "Mozambique",
                             grepl(Country, pattern = "Nigeria") ~ "Nigeria",
                             grepl(Country, pattern = "Niger") & !grepl(Country, pattern = "Nigeria") ~ "Niger",
                             grepl(Country, pattern = "Nepal") ~ "Nepal",
                             grepl(Country, pattern = "Namibia") ~ "Namibia",
                             grepl(Country, pattern = "Myanmar") ~ "Myanmar",
                             grepl(Country, pattern = "Mongolia") ~ "Mongolia",
                             grepl(Country, pattern = "Mombasa") ~ "Kenya",
                             grepl(Country, pattern = "Mexico") ~ "Mexico",
                             grepl(Country, pattern = "Mayotte") ~ "Mayotte",
                             grepl(Country, pattern = "Mauritania") ~ "Mauritania",
                             grepl(Country, pattern = "Mali") ~ "Mali",
                             grepl(Country, pattern = "Maldives") ~ "Maldives",
                             grepl(Country, pattern = "Malaysia") ~ "Malaysia",
                             grepl(Country, pattern = "Malawi") ~ "Malawi",
                             grepl(Country, pattern = "Portugal") ~ "Portugal",
                             grepl(Country, pattern = "Madagascar") ~ "Madagascar",
                             grepl(Country, pattern = "Liberia") ~ "Liberia",
                             grepl(Country, pattern = "Lesotho") ~ "Lesotho",
                             grepl(Country, pattern = "Lebanon") ~ "Lebanon",
                             grepl(Country, pattern = "Lao") ~ "Lao People's Democratic Republic",
                             grepl(Country, pattern = "Kuwait") ~ "Kuwait",
                             grepl(Country, pattern = "Kinshasa") ~ "Congo Democratic Republic of the",
                             grepl(Country, pattern = "Jordan") ~ "Jordan",
                             grepl(Country, pattern = "Japan") ~ "Japan",
                             grepl(Country, pattern = "Kenya") ~ "Kenya",
                             grepl(Country, pattern = "Jamaica") ~ "Jamaica",
                             grepl(Country, pattern = "Italy") ~ "Italy",
                             grepl(Country, pattern = "Israel") ~ "Israel",
                             grepl(Country, pattern = "Iran") ~ "Iran (Islamic Republic of)",
                             grepl(Country, pattern = "Ireland") & !grepl(Country, pattern = "Britain") ~ "Ireland",
                             grepl(Country, pattern = "Iraq") ~ "Iraq",
                             grepl(Country, pattern = "Indonesia") ~ "Indonesia",
                             grepl(Country, pattern = "India") & !grepl(Country, pattern = "British") ~ "India",
                             grepl(Country, pattern = "Hungary") ~ "Hungary",
                             grepl(Country, pattern = "Hong Kong") ~ "Hong Kong",
                             grepl(Country, pattern = "Honduras") ~ "Honduras",
                             grepl(Country, pattern = "Haiti") ~ "Haiti",
                             grepl(Country, pattern = "Guyana") ~ "Guyana",
                             grepl(Country, pattern = "Guinea Bissau") ~ "Guinea-Bissau",
                             grepl(Country, pattern = "Guinea") & !grepl(Country, pattern = "Bissau") & !grepl(Country, pattern = "Papua") & !grepl(Country, pattern = "Equatorial") ~ "Guinea",
                             grepl(Country, pattern = "Guatemala") ~ "Guatemala",
                             grepl(Country, pattern = "Guadeloupe") ~ "Guadeloupe",
                             grepl(Country, pattern = "Greece") ~ "Greece",
                             grepl(Country, pattern = "Ghana") ~ "Ghana",
                             grepl(Country, pattern = "Germany") ~ "Germany",
                             grepl(Country, pattern = "Gambia") ~ "Gambia",
                             grepl(Country, pattern = "Gabon") ~ "Gabon",
                             grepl(Country, pattern = "French Guiana") ~ "French Guiana",
                             grepl(Country, pattern = "Fiji") ~ "Fiji",
                             grepl(Country, pattern = "Ethiopia") ~ "Ethiopia",
                             grepl(Country, pattern = "Equatorial") ~ "Equatorial Guinea",
                             grepl(Country, pattern = "El Salvador") ~ "El Salvador",
                             grepl(Country, pattern = "Egypt") ~ "Egypt",
                             grepl(Country, pattern = "Ecuador") ~ "Ecuador",
                             grepl(Country, pattern = "Dominican Republic") ~ "Dominican Republic",
                             grepl(Country, pattern = "Dominica") & !grepl(Country, pattern = "Dominican Republic") ~ "Dominica",
                             grepl(Country, pattern = "Djibouti") ~ "Djibouti",
                             grepl(Country, pattern = "Democratic Republic of Congo") ~ "Congo Democratic Republic of the", 
                             grepl(Country, pattern = "Cyprus") ~ "Cyprus",
                             grepl(Country, pattern = "Cuba") ~ "Cuba",
                             grepl(Country, pattern = "voire") ~ "Côte d'Ivoire",
                             grepl(Country, pattern = "Chile") ~ "Chile",
                             grepl(Country, pattern = "Verde") ~ "Cabo Verde",
                             grepl(Country, pattern = "Chad") ~ "Chad",
                             grepl(Country, pattern = "Canada") ~ "Canada",
                             grepl(Country, pattern = "Cameroon") ~ "Cameroon",
                             grepl(Country, pattern = "Cambodia") ~ "Cambodia",
                             grepl(Country, pattern = "Burundi") ~ "Burundi",
                             grepl(Country, pattern = "Burkina Faso") ~ "Burkina Faso",
                             grepl(Country, pattern = "Brazil") ~ "Brazil",
                             grepl(Country, pattern = "Bosnia and Herzegovina") ~ "Bosnia and Herzegovina",
                             grepl(Country, pattern = "Bolivia") ~ "Bolivia (Plurinational State of)",                               
                             grepl(Country, pattern = "Bhutan") ~ "Bhutan",
                             grepl(Country, pattern = "Benin") ~ "Benin",
                             grepl(Country, pattern = "Belgium") ~ "Belgium",
                             grepl(Country, pattern = "Bangladesh") ~ "Bangladesh",
                             grepl(Country, pattern = "Azerbaijan") ~ "Azerbaijan",
                             grepl(Country, pattern = "Austria") ~ "Austria",
                             grepl(Country, pattern = "Australia") ~ "Australia",
                             grepl(Country, pattern = "Argentina") ~ "Argentina",
                             grepl(Country, pattern = "Angola") ~ "Angola",
                             grepl(Country, pattern = "Algeria") ~ "Algeria",
                             grepl(Country, pattern = "Albania") ~ "Albania",
                             grepl(Country, pattern = "Afghanistan") ~ "Afghanistan",
                             grepl(Outbreak, pattern = "Polio outbreak– The Philippines") ~ "Philippines",
                             grepl(Outbreak, pattern = "Spain") ~ "Spain",
                             grepl(Outbreak, pattern = "HIV cases–Pakistan") ~ "Pakistan",
                             grepl(Outbreak, pattern = "Diphtheria – Cox’s Bazar in Bangladesh") ~ "Bangladesh",
                             grepl(Outbreak, pattern = "Seychelles – Suspected Plague (Ex- Madagascar)") ~ "Seychelles",
                             grepl(Outbreak, pattern = "Summary of poliovirus circulation in 2016 – Pakistan") ~ "Pakistan",
                             grepl(Outbreak, pattern = "Detection of poliovirus in sewage, Brazil") ~ "Brazil",
                             grepl(Outbreak, pattern = "Yosemite National Park") ~ "United States of America",
                             grepl(Outbreak, pattern = "Confirmed international spread of wild poliovirus from Pakistan") ~ "Pakistan",
                             grepl(Outbreak, pattern = "Outbreak of illness in schools in Angola") ~ "Angola",
                             grepl(Outbreak, pattern = "Ebola Reston in pigs and humans in the Philippines - update") ~ "Philippines",
                             grepl(Outbreak, pattern = "Ebola Reston in pigs and humans in the Philippines") ~ "Philippines",
                             grepl(Outbreak, pattern = "Case of Marburg Haemorrhagic Fever imported into the Netherlands from Uganda") ~ "Netherlands",
                             grepl(Outbreak, pattern = "Fièvre hémorragique de Marburg en Ouganda - bulletin") ~ "Uganda",
                             grepl(Outbreak, pattern = "ian influenza – H5N1 infection found in a stone marten in Germany") ~ "Germany",
                             grepl(Outbreak, pattern = "Outbreak associated with Streptococcus suis in pigs in China") ~ "China",
                             grepl(Outbreak, pattern = "Avian influenza – outbreak in poultry in the Democratic People’s Republic of Korea") ~ "Korea (Democratic People's Republic of)",
                             grepl(Outbreak, pattern = "China") ~ "China",
                             grepl(Outbreak, pattern = "Viet Nam") ~ "Viet Nam",
                             grepl(Outbreak, pattern = "Thailand") ~ "Thailand",
                             grepl(Outbreak, pattern = "Taiwan") ~ "Taiwan Province of China",
                             grepl(Outbreak, pattern = "Côte d'Ivoir") ~ "Côte d'Ivoire",
                             grepl(Outbreak, pattern = "The Republic of the Congo") ~ "Congo",
                             grepl(Outbreak, pattern = "Hong Kong") ~ "Hong Kong",
                             grepl(Outbreak, pattern = "Kosovo") ~ "Kosovo",
                             grepl(Outbreak, pattern = "Ukraine") ~ "Ukraine",
                             grepl(Outbreak, pattern = "UK") ~ "United Kingdom of Great Britain and Northern Ireland",
                             grepl(Outbreak, pattern = "Comoros") ~ "Comoros",
                             grepl(Outbreak, pattern = "France") ~ "France",
                             grepl(Outbreak, pattern = "Democratic Republic of the Congo") ~ "Congo Democratic Republic of the",
                             grepl(Outbreak, pattern = "United States of America") ~ "United States of America",
                             grepl(Outbreak, pattern = "Belgium") ~ "Belgium",
                             grepl(Outbreak, pattern = "Russia") ~ "Russian Federation",
                             grepl(Outbreak, pattern = "Guinea-Bissau") ~ "Guinea-Bissau",
                             grepl(Outbreak, pattern = "Armenia") ~ "Armenia",
                             grepl(Outbreak, pattern = "Saudi Arabia") ~ "Saudi Arabia",
                             grepl(Outbreak, pattern = "Cook Islands") ~ "Cook Islands",
                             grepl(Outbreak, pattern = "Philippines") ~ "Philippines"))

## DONs related to multiple countries
DONsdf9 <- DONsdf8 %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1996 - Cerebrospinal meningitis in Africa \\(summary\\)$"), 8, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1996 - Cerebrospinal meningitis in Africa \\(summary\\) - Update$"), 11, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1996 - Cerebrospinal meningitis in Africa \\(summary\\) - Update 2$"), 12, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1996 - Cholera in Africa$") & Month == 10, 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1996 - Cholera in Africa$") & Month == 2, 6, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1996 - Global Cholera Update$"), 5, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1996 - Global Cholera Update 2$"), 6, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1996 - Yellow fever in travellers$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1997 - Meningitis in West Africa$") & Date == "1997-04-11", 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1997 - Meningitis in West Africa$") & Date == "1997-03-27", 7, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1997 - Meningitis in West Africa$") & Month == 1, 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1998 - Cholera - Vibrio cholerae O139 strain$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1998 - Cholera in Latin America and El Niño$"), 5, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1998 - Cholera in the Great Lakes Region$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1998 - Dengue$"), 16, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1998 - Hurricane Mitch, Update 4$"), 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1998 - Hurricane Mitch, Update 5$"), 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1998 - Hurricane Mitch, Update 6$"), 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1998 - Hurricane Mitch, Update 8$"), 5, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1998 - Influenza$"), 5, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1999 - Cholera in Africa$"), 7, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1999 - Cholera outbreaks$"), 6, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1999 - Sylvatic yellow fever in South America$"), 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2000 - Ebola haemorrhagic fever - Update 17$"), 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2001- Meningococcal disease in the African Meningitis Belt - Update 2$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2001- Meningococcal disease in the African Meningitis Belt - Update 7$"), 6, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2001 - Cholera in West Africa$"), 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2001 - Cholera in West Africa - Update$"), 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2001 - Meningococcal disease in the African Meningitis Belt$"), 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2001 - Meningococcal disease in the African Meningitis Belt - Update 3$"), 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2001 - Meningococcal disease in the African Meningitis Belt - Update 4$"), 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2001 - Meningococcal disease in the African Meningitis Belt - Update 5$"), 7, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2001 - Meningococcal disease, serogroup W135$"), 7, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2001 - Meningococcal disease, serogroup W135 - Update$"), 8, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2001 - Meningococcal disease, serogroup W135 - Update 2$"), 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2001 - Meningococcal disease, serogroup W135 - Update 3$"), 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2002 - Meningococcal disease in the African Meningitis Belt - Update 2$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Avian Influenza - Assessment of the current situation$"), 4, 1)) %>%
  uncount(repeated_row)
DONsdf9 <- DONsdf9 %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Avian influenza – cumulative number of cases – update 18$"), 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Avian influenza – new areas with infection in birds – update 34$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Avian influenza – situation in Cambodia – update$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Avian influenza –spread of the virus to new countries$"), 13, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Avian influenza A\\(H5N1\\) in humans - update 12: Prevention of further cases of H5N1 disease in humans,Investigation of the origins of the current outbreaks in poultry$"), 7, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Cholera in Central Africa$") & Date == "2010-10-08", 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Cholera in West Africa$") & Date == "2005-08-26", 8, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Cholera in West Africa - update$"), 8, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Circulating vaccine-derived poliovirus type 2 – African Region$") & Date == "2019-11-29", 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Circulating vaccine-derived poliovirus type 2 – African Region$") & Date == "2019-07-31", 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Circulating vaccine-derived poliovirus type 2 – Global update$"), 21, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Circulating vaccine-derived polioviruses – Horn of Africa$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Dengue fever – French Territories of the Americas$"), 5, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Early start of human influenza activity in the northern hemisphere$"), 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Early start of human influenza activity in the northern hemisphere$"), 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease outbreak – west Africa$"), 5, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease update - west Africa$") & Date == "2014-08-28", 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease update - west Africa$") & Date == "2014-08-22", 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease update - west Africa$") & Date == "2014-08-20", 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease update - west Africa$") & Date == "2014-08-19", 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease update - west Africa$") & Date == "2014-08-15", 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease update - west Africa$") & Date == "2014-08-13", 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease update - west Africa$") & Date == "2014-08-11", 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease update - West Africa$") & Date == "2014-08-08", 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease update - West Africa$") & Date == "2014-08-06", 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease update - West Africa$") & Date == "2014-08-04", 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-07-31", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-07-27", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-07-24", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-07-19", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-07-17", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-07-15", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-07-10", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-07-08", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-07-03", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-07-01", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-06-24", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-06-22", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-06-18", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-06-10", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-06-06", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-06-04", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-05-30", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-05-28", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-04-25", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-04-22", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-04-17", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease: background and summary$") & Date == "2014-04-03", 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-04-14", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & Date == "2014-04-10", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Ebola virus disease update - west Africa$") & Date == "2009-01-30", 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Extensively drug-resistant Shigella sonnei infections - Europe$"), 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Geographical spread of H5N1 avian influenza in birds - update 28$"), 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Hepatitis A outbreaks mostly affecting men who have sex with men – European Region and the Americas$"), 16, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Human infection with avian influenza A\\(H7N9\\) virus - update$") & Date == "2014-01-06", 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Human influenza A\\(H3N2\\) activity remains widespread in many countries - update 7$"), 17, 1)) %>%
  uncount(repeated_row) 
DONsdf9 <- DONsdf9 %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Human influenza A/H3N2 activity increases in many countries in central and eastern Europe - update 8$"), 26, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Human influenza A/H3N2 epidemic continues in northern hemisphere update 2$"), 13, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Human influenza activity further increases and spreads to more countries in northern hemisphere - update 4$"), 22, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Human influenza activity still increasing in many countries and moving eastwards - update 6$"), 31, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Human influenza epidemic spreads to more countries in northern hemisphere - update 3$"), 19, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza - update 113$"), 17, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza - update 114$"), 6, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza - update 115$"), 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 10$"), 16, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 12$"), 18, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 14$"), 21, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 16$"), 21, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 18$"), 23, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 20$"), 24, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 22$"), 25, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 23$"), 29, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 24$"), 29, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 25$"), 30, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 26$"), 31, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 27$"), 34, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 28$"), 34, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 29$"), 34, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 30$"), 36, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 31$"), 39, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 32$"), 40, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 33$"), 40, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 34$"), 40, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 35$"), 40, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 37$"), 43, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 38$"), 46, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 39$") & Date == "2009-05-27", 48, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 39$") & Date == "2009-05-26", 48, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 40$"), 48, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 41$"), 53, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 42$"), 61, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 43$"), 66, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 44$"), 69, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 45$"), 73, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 46$"), 74, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 47$"), 74, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 48$"), 74, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 49$"), 76, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 5$"), 7, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 50$"), 87, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 51$"), 91, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 52$"), 97, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 53$"), 106, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 54$"), 110, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 55$"), 114, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 6$"), 11, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 8.1$"), 13, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Measles – European Region$"), 7, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Measles – Global situation$"), 28, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Measles – Pacific Island Countries and Areas$"), 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Measles – The Americas$"), 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Measles – Western Pacific Region$"), 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Measles – WHO European Region$"), 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Measles outbreaks: Regions of the Americas, Europe and Africa$"), 17, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Meningococcal disease in the African Meningitis Belt$"), 11, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Meningococcal disease in the African Meningitis Belt, epidemic season 2006$"), 7, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Meningococcal disease: 2013 epidemic season in the African Meningitis Belt$"), 5, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Meningococcal disease: situation in the African Meningitis Belt$") & Date == "2012-05-24", 10, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Meningococcal disease: situation in the African Meningitis Belt$") & Date == "2012-03-23", 5, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Meningococcal Disease: situation in the African Meningitis Belt$") & Date == "2009-03-25", 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Middle East respiratory syndrome- coronavirus - update$"), 8, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\)$"), 8, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & Date == "2013-12-31", 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & Date == "2013-07-18", 2, 1)) %>%
  uncount(repeated_row) 
DONsdf9 <- DONsdf9 %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & Date == "2013-06-17", 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & Date == "2013-06-15", 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & Date == "2013-06-14", 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & Date == "2013-06-07", 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & Date == "2013-06-05", 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & Date == "2013-06-02", 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & Date == "2013-06-01", 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & Date == "2013-05-31", 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & Date == "2014-05-15", 5, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & Date == "2013-05-15", 5, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & Date == "2014-04-10", 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & Date == "2014-03-12", 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Novel coronavirus infection - update$") & Date == "2013-05-22", 8, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Novel coronavirus infection - update$") & Date == "2013-05-12", 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 100$"), 19, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 101$"), 22, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 102$"), 13, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 103$"), 13, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 104$"), 20, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 105$"), 21, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 106$"), 25, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 108$"), 27, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 109$"), 30, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 110$"), 31, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 111$"), 31, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 112$"), 31, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 56$"), 120, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 57$"), 123, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 58$"), 133, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 59$"), 21, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 60$"), 9, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 61$"), 7, 1)) %>%
  uncount(repeated_row) %>%  
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 62 \\(revised 21 August 2009\\)$"), 3, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 63$"), 3, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 64$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 65$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 71$"), 6, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 73$"), 6, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 74$"), 4, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 75$"), 3, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 76$"), 7, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 77$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 78$"), 5, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 79$"), 5, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 80$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 81$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 85$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 86$"), 2, 1)) %>%
  uncount(repeated_row) %>%  
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 96$"), 2, 1)) %>%
  uncount(repeated_row) %>%  
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Recent outbreaks of cholera in Africa$"), 6, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 45$"), 4, 1)) %>%
  uncount(repeated_row) %>%   
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 46$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 49$"), 3, 1)) %>%
  uncount(repeated_row) %>%  
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 51$"), 2, 1)) %>%
  uncount(repeated_row) %>%  
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 52$"), 3, 1)) %>%
  uncount(repeated_row) %>%  
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 53$"), 4, 1)) %>%
  uncount(repeated_row) %>%  
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 54$"), 3, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 55$"), 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 56$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 57$"), 3, 1)) %>%
  uncount(repeated_row)
DONsdf9 <- DONsdf9 %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 58$"), 2, 1)) %>%
  uncount(repeated_row) %>%  
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 59$"), 3, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 60$"), 3, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update$"), 9, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 12$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 13$"), 5, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 14$"), 3, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 15$"), 4, 1)) %>%
  uncount(repeated_row) %>%   
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 16$"), 10, 1)) %>%
  uncount(repeated_row) %>%   
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 18$"), 4, 1)) %>%
  uncount(repeated_row) %>%   
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 20$"), 8, 1)) %>%
  uncount(repeated_row) %>%   
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 21$"), 6, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 22$"), 7, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 23$"), 6, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 24$"), 6, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 25$"), 6, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 26$"), 8, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 27$"), 5, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 28$"), 6, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 29$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 30$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 32$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 33$"), 3, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 34$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 36$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - Multi-country outbreak - Update 41$"), 3, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - Multi-country outbreak - Update 42$"), 4, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - Multi-country outbreak - Update 43$"), 3, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - Multi-country outbreak - Update 44$"), 5, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - Multi-country outbreak Update 38$"), 5, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - Multi-country outbreak Update 39$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - Multi-country outbreak Update 40$"), 5, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) multi-country outbreak - Update 3$"), 10, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) multi-country outbreak - Update 4$"), 10, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) multi-country outbreak - Update 5$"), 7, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) multi-country outbreak - Update 8$"), 5, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Swine influenza - update 3$"), 4, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Swine influenza - update 4$"), 6, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Update 73 - No new deaths, but vigilance needed for imported cases$"), 5, 1)) %>%
  uncount(repeated_row) 
DONsdf9 <- DONsdf9 %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Update 74 - Global decline in cases and deaths continues$"), 4, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Update on polio in central Africa$"), 3, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Update on polio in central Africa - polio confirmed in Equatorial Guinea, linked to outbreak in Cameroon$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^West Nile Virus Infection \\(WNV\\) in Europe$"), 5, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Widespread human influenza activity persists in northern hemisphere - update 5$"), 23, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Wild poliovirus in the Horn of Africa – update$"), 4, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Yellow Fever - West and Central Africa$"), 9, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Zika virus infection – Region of the Americas$"), 4, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Poliovirus in South Sudan and Madagascar$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Poliomyelitis in Nigeria and West/Central Africa$"), 8, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1996 - Ebola infection in Côte d'Ivoire/Liberia$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1996 - Dengue/dengue haemorrhagic fever in the Philippines and Malaysia$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Lassa Fever – Benin, Togo and Burkina Faso$"), 3, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1996 - Cholera in Rwanda and Zaire$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Avian influenza – situation in Viet Nam and Cambodia – update 12$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Avian influenza – situation in Viet Nam and Cambodia - update 8$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Avian influenza A\\(H5N1\\) - update 22: First data on patients from Viet Nam, Clinical data from Hong Kong 1997, Susceptibility of H5N1 viruses to antiviral drugs$"), 3, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Avian influenza A\\(H5N1\\) - update 18: FAO/OIE/WHO Technical Consultation on the Control of Avian Influenza, Situation \\(human\\) in Thailand and Viet Nam$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2000 - Meningococcal disease in France and the United Kingdom$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2000 - Meningococcal disease in France and the United Kingdom$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2001 - Ebola haemorrhagic fever in Gabon/The Republic of the Congo - Update 10$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2002 - Ebola haemorrhagic fever in Gabon/The Republic of the Congo - Update 21$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2002 - Ebola haemorrhagic fever in Gabon/The Republic of the Congo - Update 20$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2002 - Ebola haemorrhagic fever in Gabon/The Republic of the Congo - Update 16$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2002 - Ebola haemorrhagic fever in Gabon/The Republic of the Congo - Update 15$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2002 - Ebola haemorrhagic fever in Gabon/The Republic of the Congo - Update 14$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^2002 - Ebola haemorrhagic fever in Gabon/The Republic of the Congo Update 13$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Zika virus infection – Brazil and Colombia$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Poliomyelitis in West Africa: Togo, Burkina Faso and Ghana$"), 3, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Botulism in the United States and Canada$"), 2, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^EHEC outbreak: Increase in cases in Germany$"), 9, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Cholera in Central Africa$"), 4, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Cholera in Chad, Mozambique and Zambia$"), 3, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Avian influenza A(H5N1) - update 28: Reports of infection in domestic cats (Thailand), Situation (human) in Thailand, Situation (poultry) in Japan and China$"), 3, 1)) %>%
  uncount(repeated_row) %>% 
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Zika virus infection – Dominica and Cuba$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Avian influenza A(H5N1) - update 21:Global surveillance guidelines, Investigation of possible human-to-human transmission: data on second sister in family cluster in Viet Nam$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Zika virus infection – Guyana, Barbados and Ecuador$"), 3, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Avian influenza – situation in Thailand, Indonesia – update 36$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1996 - Dengue/dengue haemorrhagic fever in Malaysia and Indonesia$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1996 - Diphtheria in Laos and Thailand$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^1999 - Hendra-like virus in Malaysia and Singapore$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Influenza-like illness in the United States and Mexico$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Swine flu illness in the United States and Mexico - update 2$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^New virus from Arenaviridae family in South Africa and Zambia - Update$"), 2, 1)) %>%
  uncount(repeated_row) %>%
  mutate(repeated_row = ifelse(grepl(Outbreak, pattern = "^Unknown disease in South Africa and Zambia$"), 2, 1)) %>%
  uncount(repeated_row) 
  
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1996 - Cerebrospinal meningitis in Africa \\(summary\\)$"), "Country"] <- c("Benin", "Burkina Faso", "Cameroon", "Central African Republic", "Chad", "Mali", "Niger", "Nigeria")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1996 - Cerebrospinal meningitis in Africa \\(summary\\) - Update$"), "Country"] <- c("Benin", "Burkina Faso", "Cameroon", "Central African Republic", "Chad", "Ghana", "Mali", "Niger", "Nigeria", "Tanzania United Republic of", "Togo")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1996 - Cerebrospinal meningitis in Africa \\(summary\\) - Update 2$"), "Country"] <- c("Benin", "Burkina Faso", "Cameroon", "Central African Republic", "Chad", "Ghana", "Mali", "Niger", "Nigeria", "Tanzania United Republic of", "Togo", "Congo Democratic Republic of the")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1996 - Cholera in Africa$") & DONsdf9$Month == 10, "Country"] <- c("Guinea-Bissau", "Senegal", "Togo")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1996 - Cholera in Africa$") & DONsdf9$Month == 2, "Country"] <- c("Burkina Faso", "Cabo Verde", "Mali", "Senegal", "Argentina", "Ecuador")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1996 - Ebola-like Reston virus in monkeys$"), "Country"] <- "United States of America"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1996 - Global Cholera Update$"), "Country"] <- c("Cabo Verde", "Côte d'Ivoire", "Iran (Islamic Republic of)", "Iraq", "Senegal")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1996 - Global Cholera Update 2$"), "Country"] <- c("Cabo Verde", "Niger", "Nigeria", "Senegal", "Somalia", "Mexico")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1996 - Rwanda repatriation movement$"), "Country"] <- "Rwanda"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1996 - Yellow fever in travellers$"), "Country"] <- c("Switzerland", "United States of America")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1997 - Meningitis in West Africa$") & DONsdf9$Date == "1997-04-11", "Country"] <- c("Benin", "Burkina Faso", "Ghana", "Mali", "Gambia", "Rwanda", "Togo", "Niger", "Senegal")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1997 - Meningitis in West Africa$") & DONsdf9$Date == "1997-03-27", "Country"] <- c("Benin", "Burkina Faso", "Ghana", "Mali", "Gambia", "Togo", "Niger")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1997 - Meningitis in West Africa$") & DONsdf9$Month == 1, "Country"] <- c("Burkina Faso", "Ghana", "Mali", "Togo")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1997 - Viral meningitis in Gaza$"), "Country"] <- "Gaza"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1998 - Cholera - Vibrio cholerae O139 strain$"), "Country"] <- c("India", "Hong Kong")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1998 - Cholera in Latin America and El Niño$"), "Country"] <- c("Bolivia (Plurinational State of)", "Honduras", "Ecuador", "Peru", "Nicaragua")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1998 - Cholera in Sulaimania governorate in northern Iraq$"), "Country"] <- "Iraq"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1998 - Cholera in the Great Lakes Region$"), "Country"] <- c("Rwanda", "Congo Democratic Republic of the")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1998 - Dengue$"), "Country"] <- c("Malaysia", "Taiwan Province of China", "Cambodia", "Viet Nam", "Thailand", "Philippines", "Indonesia", "Myanmar", "Guam", "Cook Islands", "Fiji", "New Caledonia", "Kiribati", "Brazil", "Venezuela (Bolivarian Republic of)", "Colombia") 
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1998 - Cholera in Sulaimania governorate in northern Iraq$"), "Country"] <- "Iraq"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1998 - Hurricane Mitch, Update 4$"), "Country"] <- c("Nicaragua", "Honduras", "Guatemala")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1998 - Hurricane Mitch, Update 5$"), "Country"] <- c("Nicaragua", "Honduras", "Guatemala")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1998 - Hurricane Mitch, Update 6$"), "Country"] <- c("Nicaragua", "El Salvador", "Honduras", "Guatemala")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1998 - Hurricane Mitch, Update 8$"), "Country"] <- c("Belize", "Nicaragua", "El Salvador", "Honduras", "Guatemala")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1998 - Influenza$"), "Country"] <- c("United States of America", "Canada", "Israel", "Iran (Islamic Republic of)", "Japan")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1999 - Cholera in Africa$"), "Country"] <- c("Kenya", "Mozambique", "Somalia", "Uganda", "Tanzania United Republic of", "Zambia", "Zimbabwe")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1999 - Cholera outbreaks$"), "Country"] <- c("Burundi", "Madagascar", "Honduras", "Nicaragua", "Afghanistan", "Brunei Darussalam") 
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1999 - Sylvatic yellow fever in South America$"), "Country"] <- c("Brazil", "Bolivia (Plurinational State of)", "Colombia", "Peru")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2000 - Ebola haemorrhagic fever - Update"), "Country"] <- "Uganda"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2001- Meningococcal disease in the African Meningitis Belt - Update 2$"), "Country"] <- c("Chad", "Ethiopia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2001- Meningococcal disease in the African Meningitis Belt - Update 7$"), "Country"] <- c("Benin", "Ethiopia", "Chad", "Burkina Faso", "Central African Republic", "Niger")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2001- Yellow fever - Update 6$"), "Country"] <- "Côte d'Ivoire"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2001 - Cholera in south Africa - Update 14$"), "Country"] <- "South Africa"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2001 - Cholera in West Africa$"), "Country"] <- c("Burkina Faso", "Guinea", "Côte d'Ivoire")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2001 - Cholera in West Africa - Update$"), "Country"] <- c("Burkina Faso", "Guinea", "Côte d'Ivoire")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2001 - Meningococcal disease in the African Meningitis Belt$"), "Country"] <- c("Benin", "Chad", "Ethiopia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2001 - Meningococcal disease in the African Meningitis Belt - Update 3$"), "Country"] <- c("Burkina Faso", "Benin", "Cameroon", "Ethiopia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2001 - Meningococcal disease in the African Meningitis Belt - Update 4$"), "Country"] <- c("Burkina Faso", "Chad", "Niger")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2001 - Meningococcal disease in the African Meningitis Belt - Update 5$"), "Country"] <- c("Burkina Faso", "Benin", "Chad", "Central African Republic", "Niger", "Ethiopia", "Gambia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2001 - Meningococcal disease, serogroup W135$"), "Country"] <- c("Burkina Faso", "Central African Republic", "France", "Norway", "United Kingdom of Great Britain and Northern Ireland", "Saudi Arabia", "Singapore")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2001 - Meningococcal disease, serogroup W135 - Update$"), "Country"] <- c("Burkina Faso", "Central African Republic", "Denmark", "France", "Norway", "United Kingdom of Great Britain and Northern Ireland", "Saudi Arabia", "Singapore")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2001 - Meningococcal disease, serogroup W135 - Update 2$"), "Country"] <- c("Burkina Faso", "Niger", "Central African Republic", "Denmark", "France", "Norway", "United Kingdom of Great Britain and Northern Ireland", "Saudi Arabia", "Singapore")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2001 - Meningococcal disease, serogroup W135 - Update 3$"), "Country"] <- "France"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2002 - Meningococcal disease in the African Meningitis Belt - Update 2$"), "Country"] <- c("Burkina Faso", "Niger")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Avian Influenza - Assessment of the current situation$"), "Country"] <- c("China", "Indonesia", "Thailand", "Viet Nam")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Avian influenza – cumulative number of cases – update 18$"), "Country"] <- c("Cambodia", "Thailand", "Viet Nam")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Avian influenza – new areas with infection in birds – update 34$"), "Country"] <- c("Turkey", "Romania")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Avian influenza – situation in Cambodia – update$"), "Country"] <- "Cambodia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Avian influenza –spread of the virus to new countries$"), "Country"] <- c("Iraq", "Nigeria", "Azerbaijan", "Bulgaria", "Greece", "Italy", "Slovenia", "Iran (Islamic Republic of)", "Austria", "Germany", "Egypt", "India", "France")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Avian influenza A\\(H5N1\\) in humans - update 12: Prevention of further cases of H5N1 disease in humans,Investigation of the origins of the current outbreaks in poultry$"), "Country"] <- c("Japan", "Cambodia", "Korea Republic of", "Thailand", "Viet Nam", "Indonesia", "Lao People's Democratic Republic")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Avian influenza H5N1 infection in humans: urgent need to eliminate the animal reservoir - update 5$"), "Country"] <- "Viet Nam"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Cholera in Central Africa$") & DONsdf9$Date == "2010-10-08", "Country"] <- c("Cameroon", "Chad", "Niger", "Nigeria")  
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Cholera in West Africa$") & DONsdf9$Date == "2005-08-26", "Country"] <- c("Burkina Faso", "Guinea", "Guinea-Bissau", "Liberia", "Mali", "Mauritania", "Niger", "Senegal")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Cholera in West Africa - update$"), "Country"] <- c("Benin", "Burkina Faso", "Guinea", "Guinea-Bissau", "Mali", "Mauritania", "Niger", "Senegal")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Circulating vaccine-derived poliovirus type 2 – African Region$") & DONsdf9$Date == "2019-11-29", "Country"] <- c("Nigeria", "Benin", "Cameroon", "Chad", "Côte d'Ivoire", "Ghana", "Niger", "Togo", "Zambia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Circulating vaccine-derived poliovirus type 2 – African Region$") & DONsdf9$Date == "2019-07-31", "Country"] <- c("Nigeria", "Angola", "Cameroon", "Central African Republic", "Congo Democratic Republic of the", "Ethiopia", "Kenya", "Niger", "Somalia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Circulating vaccine-derived poliovirus type 2 – Global update$"), "Country"] <- c("Angola", "Benin", "Burkina Faso", "Cameroon", "Central African Republic", "Chad", "Côte d'Ivoire", "Congo Democratic Republic of the", "Ethiopia", "Ghana", "Guinea", "Kenya", "Liberia", "Mali", "Niger", "Nigeria", "Congo", "Senegal", "Sierra Leone", "South Sudan", "Togo")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Circulating vaccine-derived polioviruses – Horn of Africa$"), "Country"] <- c("Somalia", "Kenya")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Dengue fever – French Territories of the Americas$"), "Country"] <- c("French Guiana", "Guadeloupe", "Martinique", "Saint Martin (French part)", "Saint Barthélemy")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Early start of human influenza activity in the northern hemisphere$"), "Country"] <- c("Canada", "United States of America", "Finland", "France", "Israel", "Norway", "Portugal", "Spain", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease$") & DONsdf9$Date == "2020-01-16", "Country"] <- c("Congo Democratic Republic of the")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease outbreak – west Africa$"), "Country"] <- c("Guinea", "Liberia", "Sierra Leone", "Nigeria", "Senegal")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease update - west Africa$") & DONsdf9$Date == "2014-08-28", "Country"] <- c("Guinea", "Liberia", "Sierra Leone", "Nigeria")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease update - west Africa$") & DONsdf9$Date == "2014-08-22", "Country"] <- c("Guinea", "Liberia", "Sierra Leone", "Nigeria")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease update - west Africa$") & DONsdf9$Date == "2014-08-20", "Country"] <- c("Guinea", "Liberia", "Sierra Leone", "Nigeria")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease update - west Africa$") & DONsdf9$Date == "2014-08-19", "Country"] <- c("Guinea", "Liberia", "Sierra Leone", "Nigeria")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease update - west Africa$") & DONsdf9$Date == "2014-08-15", "Country"] <- c("Guinea", "Liberia", "Sierra Leone", "Nigeria")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease update - west Africa$") & DONsdf9$Date == "2014-08-13", "Country"] <- c("Guinea", "Liberia", "Sierra Leone", "Nigeria")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease update - west Africa$") & DONsdf9$Date == "2014-08-11", "Country"] <- c("Guinea", "Liberia", "Sierra Leone", "Nigeria")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease update - West Africa$") & DONsdf9$Date == "2014-08-08", "Country"] <- c("Guinea", "Liberia", "Sierra Leone", "Nigeria")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease update - West Africa$") & DONsdf9$Date == "2014-08-06", "Country"] <- c("Guinea", "Liberia", "Sierra Leone", "Nigeria")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease update - West Africa$") & DONsdf9$Date == "2014-08-04", "Country"] <- c("Guinea", "Liberia", "Sierra Leone", "Nigeria")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-07-31", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-07-27", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-07-24", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-07-19", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-07-17", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-07-15", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-07-10", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-07-08", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-07-03", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-07-01", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-06-24", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-06-22", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-06-18", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-06-10", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-06-06", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-06-04", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-05-30", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-05-28", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-05-24", "Country"] <- "Guinea"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-05-15", "Country"] <- "Guinea"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-05-12", "Country"] <- "Guinea"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-05-09", "Country"] <- "Guinea"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-05-08", "Country"] <- "Guinea"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-05-06", "Country"] <- "Guinea"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-05-02", "Country"] <- "Guinea"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-04-28", "Country"] <- "Guinea"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-04-25", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-04-22", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-04-19", "Country"] <- "Guinea"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-04-17", "Country"] <- c("Guinea", "Liberia", "Sierra Leone")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-04-14", "Country"] <- c("Guinea", "Liberia", "Mali")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-04-10", "Country"] <- c("Guinea", "Liberia", "Mali")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-04-07", "Country"] <- "Guinea"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-04-05", "Country"] <- "Guinea"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-04-02", "Country"] <- "Guinea"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease, West Africa – update$") & DONsdf9$Date == "2014-04-01", "Country"] <- "Guinea"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Ebola virus disease: background and summary$") & DONsdf9$Date == "2014-04-03", "Country"] <- c("Guinea", "Liberia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Efforts must be intensified to control Zimbabwe cholera outbreak [WHO PRESS RELEASE]$") & DONsdf9$Date == "2014-04-03", "Country"] <- "Zimbabwe"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Extensively drug-resistant Shigella sonnei infections - Europe$"), "Country"] <- c("United Kingdom of Great Britain and Northern Ireland", "Denmark", "Spain")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Geographical spread of H5N1 avian influenza in birds - update 28$"), "Country"] <- c("Kazakhstan", "Russian Federation", "Mongolia", "China", "Viet Nam", "Cambodia", "Thailand", "Lao People's Democratic Republic", "Indonesia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^H5N1 avian influenza in domestic cats$"), "Country"] <- "Germany"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Hantavirus Pulmonary Syndrome – Argentine Republic$"), "Country"] <- "Argentina"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Hepatitis A outbreaks mostly affecting men who have sex with men – European Region and the Americas$"), "Country"] <- c("United States of America", "Austria", "Belgium", "Denmark", "Finland", "France", "Germany", "Ireland", "Italy", "Netherlands", "Norway", "Portugal", "Slovenia", "Spain", "Sweden", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Human infection with avian influenza A\\(H5N1\\) virus - update$") & DONsdf9$Date == "2014-01-09", "Country"] <- "Canada"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Human infection with avian influenza A\\(H7N9\\) virus - update$"), "Country"] <- "China"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Human infection with avian influenza A\\(H7N9\\) virus – update$"), "Country"] <- "China"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Human infection with avian influenza A\\(H7N9\\) virus - update$") & DONsdf9$Date == "2014-01-06", "Country"] <- c("China", "Hong Kong")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Human infection with avian influenza A\\(H7N9\\) virus - update$") & DONsdf9$Date == "2014-02-17", "Country"] <- "Malaysia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Human influenza A\\(H3N2\\) activity remains widespread in many countries - update 7$"), "Country"] <- c("Belgium", "Canada", "Croatia", "Czechia", "Finland", "France", "Denmark", "Germany", "Israel", "Latvia", "Norway", "Portugal", "Korea Republic of", "Romania", "Switzerland", "United Kingdom of Great Britain and Northern Ireland", "United States of America")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Human influenza A/H3N2 activity increases in many countries in central and eastern Europe - update 8$"), "Country"] <- c("Austria", "Belgium", "Canada", "Croatia", "France", "Denmark", "Germany", "Israel", "Italy", "Japan", "Latvia", "Norway", "Romania", "Russian Federation", "Slovenia", "Sweden", "Switzerland", "Ukraine", "United Kingdom of Great Britain and Northern Ireland", "United States of America", "Greece", "Guyana", "Hong Kong", "Hungary", "Morocco", "Portugal")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Human influenza A/H3N2 epidemic continues in northern hemisphere update 2$"), "Country"] <- c("Canada", "France", "Israel", "Italy", "Latvia", "Norway", "Spain", "United Kingdom of Great Britain and Northern Ireland", "United States of America", "Chile", "Denmark", "Guyana", "Switzerland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Human influenza activity further increases and spreads to more countries in northern hemisphere - update 4$"), "Country"] <- c("Canada", "Denmark", "Finland", "France", "Hong Kong", "Italy", "Japan", "Latvia", "Norway", "Portugal", "Russian Federation", "Spain", "Switzerland", "Ukraine", "United Kingdom of Great Britain and Northern Ireland", "United States of America", "Austria", "Chile", "Germany", "Hungary", "Iceland", "Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Human influenza activity still increasing in many countries and moving eastwards - update 6$"), "Country"] <- c("Czechia", "Finland", "Greece", "Israel", "Russian Federation", "Switzerland", "Ukraine", "Belgium", "France", "Germany", "Latvia", "Norway", "Portugal", "Spain", "United States of America", "United Kingdom of Great Britain and Northern Ireland", "Canada", "Mexico", "Algeria", "Austria", "Chile", "Croatia", "Hong Kong", "Hungary", "Iceland", "Japan", "Madagascar", "Serbia", "Montenegro", "Slovenia", "Thailand")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Human influenza epidemic spreads to more countries in northern hemisphere - update 3$"), "Country"] <- c("Austria", "Canada", "Denmark", "Finland", "Morocco", "Norway", "Portugal", "Korea Republic of", "Russian Federation", "Spain", "Switzerland", "United Kingdom of Great Britain and Northern Ireland", "United States of America", "Czechia", "Germany", "Hong Kong", "Italy", "Thailand", "Ukraine")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza - update 113$"), "Country"] <- c("South Africa", "Ghana", "India", "Bangladesh", "Thailand", "Cambodia", "Singapore", "Malaysia", "New Zealand", "Australia", "Chile", "Argentina", "Costa Rica", "Colombia", "Peru", "Bolivia (Plurinational State of)", "Brazil")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza - update 114$"), "Country"] <- c("India", "New Zealand", "Australia", "Chile", "Argentina", "South Africa")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza - update 115$"), "Country"] <- c("India", "New Zealand", "Australia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 10$"), "Country"] <- c("Mexico", "United States of America", "Austria", "Canada", "Hong Kong", "Costa Rica", "Denmark", "France", "Germany", "Israel", "Netherlands", "New Zealand", "Korea Republic of", "Spain", "Switzerland", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 12$"), "Country"] <- c("Mexico", "United States of America", "Austria", "Canada", "Hong Kong", "Costa Rica", "Denmark", "France", "Germany", "Ireland", "Israel", "Italy", "Netherlands", "New Zealand", "Korea Republic of", "Spain", "Switzerland", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 14$"), "Country"] <- c("Mexico", "United States of America", "Austria", "Canada", "Hong Kong", "Costa Rica", "Colombia", "Denmark", "El Salvador", "France", "Germany", "Ireland", "Israel", "Italy", "Netherlands", "New Zealand", "Portugal", "Korea Republic of", "Spain", "Switzerland", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 16$"), "Country"] <- c("Mexico", "United States of America", "Austria", "Canada", "Hong Kong", "Costa Rica", "Colombia", "Denmark", "El Salvador", "France", "Germany", "Ireland", "Israel", "Italy", "Netherlands", "New Zealand", "Portugal", "Korea Republic of", "Spain", "Switzerland", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 18$"), "Country"] <- c("Mexico", "United States of America", "Austria", "Canada", "Hong Kong", "Costa Rica", "Colombia", "Denmark", "El Salvador", "France", "Germany", "Guatemala", "Ireland", "Israel", "Italy", "Netherlands", "New Zealand", "Portugal", "Korea Republic of", "Spain", "Sweden", "Switzerland", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 20$"), "Country"] <- c("Mexico", "United States of America", "Austria", "Canada", "Hong Kong", "Costa Rica", "Colombia", "Denmark", "El Salvador", "France", "Germany", "Guatemala", "Ireland", "Israel", "Italy", "Netherlands", "New Zealand", "Poland", "Portugal", "Korea Republic of", "Spain", "Sweden", "Switzerland", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 22$"), "Country"] <- c("Mexico", "United States of America", "Austria", "Brazil", "Canada", "Hong Kong", "Costa Rica", "Colombia", "Denmark", "El Salvador", "France", "Germany", "Guatemala", "Ireland", "Israel", "Italy", "Netherlands", "New Zealand", "Poland", "Portugal", "Korea Republic of", "Spain", "Sweden", "Switzerland", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 23$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Brazil", "Canada", "Hong Kong", "Costa Rica", "Colombia", "Denmark", "El Salvador", "France", "Germany", "Guatemala", "Ireland", "Israel", "Italy", "Japan", "Netherlands", "New Zealand", "Panama", "Poland", "Portugal", "Korea Republic of", "Spain", "Sweden", "Switzerland", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 24$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Brazil", "Canada", "Hong Kong", "Colombia", "Costa Rica", "Denmark", "El Salvador", "France", "Germany", "Guatemala", "Ireland", "Israel", "Italy", "Japan", "Netherlands", "New Zealand", "Panama", "Poland", "Portugal", "Korea Republic of", "Spain", "Sweden", "Switzerland", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 25$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Brazil", "Canada", "Hong Kong", "Colombia", "Costa Rica", "Denmark", "El Salvador", "France", "Germany", "Guatemala", "Ireland", "Israel", "Italy", "Japan", "Netherlands", "New Zealand", "Norway", "Panama", "Poland", "Portugal", "Korea Republic of", "Spain", "Sweden", "Switzerland", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 26$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Brazil", "Canada", "China", "Hong Kong", "Colombia", "Costa Rica", "Denmark", "El Salvador", "France", "Germany", "Guatemala", "Ireland", "Israel", "Italy", "Japan", "Netherlands", "New Zealand", "Norway", "Panama", "Poland", "Portugal", "Korea Republic of", "Spain", "Sweden", "Switzerland", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 27$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Brazil", "Canada", "China", "Hong Kong", "Colombia", "Costa Rica", "Cuba", "Denmark", "El Salvador", "Finland", "France", "Germany", "Guatemala", "Ireland", "Israel", "Italy", "Japan", "Netherlands", "New Zealand", "Norway", "Panama", "Poland", "Portugal", "Korea Republic of", "Spain", "Sweden", "Switzerland", "Thailand", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 28$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Brazil", "Canada", "China", "Hong Kong", "Colombia", "Costa Rica", "Cuba", "Denmark", "El Salvador", "Finland", "France", "Germany", "Guatemala", "Ireland", "Israel", "Italy", "Japan", "Netherlands", "New Zealand", "Norway", "Panama", "Poland", "Portugal", "Korea Republic of", "Spain", "Sweden", "Switzerland", "Thailand", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 29$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Belgium", "Brazil", "Canada", "China", "Colombia", "Costa Rica", "Cuba", "Denmark", "El Salvador", "Finland", "France", "Germany", "Guatemala", "Ireland", "Israel", "Italy", "Japan", "Netherlands", "New Zealand", "Norway", "Panama", "Poland", "Portugal", "Korea Republic of", "Spain", "Sweden", "Switzerland", "Thailand", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 30$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Belgium", "Brazil", "Canada", "China", "Colombia", "Costa Rica", "Cuba", "Denmark", "Ecuador", "El Salvador", "Finland", "France", "Germany", "Guatemala", "Ireland", "Israel", "Italy", "Japan", "Netherlands", "New Zealand", "Norway", "Panama", "Peru", "Poland", "Portugal", "Korea Republic of", "Spain", "Sweden", "Switzerland", "Thailand", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 31$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Belgium", "Brazil", "Canada", "China", "Colombia", "Costa Rica", "Cuba", "Denmark", "Ecuador", "El Salvador", "Finland", "France", "Germany", "Guatemala", "India", "Ireland", "Israel", "Italy", "Japan", "Malaysia", "Netherlands", "New Zealand", "Norway", "Panama", "Peru", "Poland", "Portugal", "Korea Republic of", "Spain", "Sweden", "Switzerland", "Thailand", "Turkey", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 32$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Belgium", "Brazil", "Canada", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Denmark", "Ecuador", "El Salvador", "Finland", "France", "Germany", "Guatemala", "India", "Ireland", "Israel", "Italy", "Japan", "Malaysia", "Netherlands", "New Zealand", "Norway", "Panama", "Peru", "Poland", "Portugal", "Korea Republic of", "Spain", "Sweden", "Switzerland", "Thailand", "Turkey", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 33$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Belgium", "Brazil", "Canada", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Denmark", "Ecuador", "El Salvador", "Finland", "France", "Germany", "Guatemala", "India", "Ireland", "Israel", "Italy", "Japan", "Malaysia", "Netherlands", "New Zealand", "Norway", "Panama", "Peru", "Poland", "Portugal", "Korea Republic of", "Spain", "Sweden", "Switzerland", "Thailand", "Turkey", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 34$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Belgium", "Brazil", "Canada", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Denmark", "Ecuador", "El Salvador", "Finland", "France", "Germany", "Guatemala", "India", "Ireland", "Israel", "Italy", "Japan", "Malaysia", "Netherlands", "New Zealand", "Norway", "Panama", "Peru", "Poland", "Portugal", "Korea Republic of", "Spain", "Sweden", "Switzerland", "Thailand", "Turkey", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 35$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Belgium", "Brazil", "Canada", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Denmark", "Ecuador", "El Salvador", "Finland", "France", "Germany", "Guatemala", "India", "Ireland", "Israel", "Italy", "Japan", "Malaysia", "Netherlands", "New Zealand", "Norway", "Panama", "Peru", "Poland", "Portugal", "Korea Republic of", "Spain", "Sweden", "Switzerland", "Thailand", "Turkey", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 37$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Belgium", "Brazil", "Canada", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Denmark", "Ecuador", "El Salvador", "Finland", "France", "Germany", "Greece", "Guatemala", "India", "Ireland", "Israel", "Italy", "Japan", "Malaysia", "Netherlands", "New Zealand", "Norway", "Panama", "Peru", "Philippines", "Poland", "Portugal", "Korea Republic of", "Russian Federation", "Spain", "Sweden", "Switzerland", "Thailand", "Turkey", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 38$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Belgium", "Brazil", "Canada", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Denmark", "Ecuador", "El Salvador", "Finland", "France", "Germany", "Greece", "Guatemala", "Honduras", "Iceland", "India", "Ireland", "Israel", "Italy", "Japan", "Kuwait", "Malaysia", "Netherlands", "New Zealand", "Norway", "Panama", "Peru", "Philippines", "Poland", "Portugal", "Korea Republic of", "Russian Federation", "Spain", "Sweden", "Switzerland", "Thailand", "Turkey", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 39$") & DONsdf9$Date == "2009-05-27", "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Bahrain", "Belgium", "Brazil", "Canada", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Denmark", "Ecuador", "El Salvador", "Finland", "France", "Germany", "Greece", "Guatemala", "Honduras", "Iceland", "India", "Ireland", "Israel", "Italy", "Japan", "Kuwait", "Malaysia", "Netherlands", "New Zealand", "Norway", "Panama", "Peru", "Philippines", "Poland", "Portugal", "Korea Republic of", "Russian Federation", "Singapore", "Spain", "Sweden", "Switzerland", "Thailand", "Turkey", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 39$") & DONsdf9$Date == "2009-05-26", "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Bahrain", "Belgium", "Brazil", "Canada", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Denmark", "Ecuador", "El Salvador", "Finland", "France", "Germany", "Greece", "Guatemala", "Honduras", "Iceland", "India", "Ireland", "Israel", "Italy", "Japan", "Kuwait", "Malaysia", "Netherlands", "New Zealand", "Norway", "Panama", "Peru", "Philippines", "Poland", "Portugal", "Korea Republic of", "Russian Federation", "Singapore", "Spain", "Sweden", "Switzerland", "Thailand", "Turkey", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 40$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Bahrain", "Belgium", "Brazil", "Canada", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Denmark", "Ecuador", "El Salvador", "Finland", "France", "Germany", "Greece", "Guatemala", "Honduras", "Iceland", "India", "Ireland", "Israel", "Italy", "Japan", "Kuwait", "Malaysia", "Netherlands", "New Zealand", "Norway", "Panama", "Peru", "Philippines", "Poland", "Portugal", "Korea Republic of", "Russian Federation", "Singapore", "Spain", "Sweden", "Switzerland", "Thailand", "Turkey", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 41$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Bahrain", "Belgium", "Brazil", "Canada", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Czechia", "Denmark", "Dominican Republic", "Ecuador", "El Salvador", "Finland", "France", "Germany", "Greece", "Guatemala", "Honduras", "Iceland", "India", "Ireland", "Israel", "Italy", "Japan", "Kuwait", "Malaysia", "Netherlands", "New Zealand", "Norway", "Panama", "Peru", "Philippines", "Poland", "Portugal", "Korea Republic of", "Romania", "Russian Federation", "Singapore", "Slovakia", "Spain", "Sweden", "Switzerland", "Thailand", "Turkey", "United Kingdom of Great Britain and Northern Ireland", "Uruguay")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 42$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Bahrain", "Belgium", "Bolivia (Plurinational State of)", "Brazil", "Canada", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Cyprus", "Czechia", "Denmark", "Dominican Republic", "Ecuador", "El Salvador", "Estonia", "Finland", "France", "Germany", "Greece", "Guatemala", "Honduras", "Hungary", "Iceland", "India", "Ireland", "Israel", "Italy", "Jamaica", "Japan", "Kuwait", "Malaysia", "Netherlands", "New Zealand", "Norway", "Panama", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Korea Republic of", "Romania", "Russian Federation", "Singapore", "Slovakia", "Spain", "Sweden", "Switzerland", "Thailand", "Turkey", "United Kingdom of Great Britain and Northern Ireland", "Uruguay", "Venezuela (Bolivarian Republic of)", "Viet Nam")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 43$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Bahamas", "Bahrain", "Belgium", "Bolivia (Plurinational State of)", "Brazil", "Bulgaria", "Canada", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Cyprus", "Czechia", "Denmark", "Dominican Republic", "Ecuador", "El Salvador", "Egypt", "Estonia", "Finland", "France", "Germany", "Greece", "Guatemala", "Honduras", "Hungary", "Iceland", "India", "Ireland", "Israel", "Italy", "Jamaica", "Japan", "Kuwait", "Lebanon", "Malaysia", "Netherlands", "New Zealand", "Nicaragua", "Norway", "Panama", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Korea Republic of", "Romania", "Russian Federation", "Singapore", "Slovakia", "Spain", "Sweden", "Switzerland", "Thailand", "Turkey", "United Kingdom of Great Britain and Northern Ireland", "Uruguay", "Venezuela (Bolivarian Republic of)", "Viet Nam")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 44$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Bahamas", "Bahrain", "Barbados", "Belgium", "Bolivia (Plurinational State of)", "Brazil", "Bulgaria", "Canada", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Cyprus", "Czechia", "Denmark", "Dominican Republic", "Ecuador", "El Salvador", "Egypt", "Estonia", "Finland", "France", "Germany", "Greece", "Guatemala", "Honduras", "Hungary", "Iceland", "India", "Ireland", "Israel", "Italy", "Jamaica", "Japan", "Kuwait", "Lebanon", "Luxembourg", "Malaysia", "Netherlands", "New Zealand", "Nicaragua", "Norway", "Panama", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Korea Republic of", "Romania", "Russian Federation", "Saudi Arabia", "Singapore", "Slovakia", "Spain", "Sweden", "Switzerland", "Thailand", "Turkey", "United Kingdom of Great Britain and Northern Ireland", "Uruguay", "Venezuela (Bolivarian Republic of)", "Viet Nam")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 45$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Bahamas", "Bahrain", "Barbados", "Belgium", "Bolivia (Plurinational State of)", "Brazil", "Bulgaria", "Canada", "Cayman Islands", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Cyprus", "Czechia", "Denmark", "Dominica", "Dominican Republic", "Ecuador", "El Salvador", "Egypt", "Estonia", "Finland", "France", "Germany", "Greece", "Guatemala", "Honduras", "Hungary", "Iceland", "India", "Ireland", "Israel", "Italy", "Jamaica", "Japan", "Kuwait", "Lebanon", "Luxembourg", "Malaysia", "Netherlands", "New Zealand", "Nicaragua", "Norway", "Panama", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Korea Republic of", "Romania", "Russian Federation", "Saudi Arabia", "Singapore", "Slovakia", "Spain", "Sweden", "Switzerland", "Thailand", "Trinidad and Tobago", "Turkey", "United Arab Emirates", "United Kingdom of Great Britain and Northern Ireland", "Uruguay", "Venezuela (Bolivarian Republic of)", "Viet Nam")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 46$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Bahamas", "Bahrain", "Barbados", "Belgium", "Bolivia (Plurinational State of)", "Brazil", "Bulgaria", "Canada", "Cayman Islands", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Cyprus", "Czechia", "Denmark", "Dominica", "Dominican Republic", "Ecuador", "El Salvador", "Egypt", "Estonia", "Finland", "France", "Germany", "Greece", "Guatemala", "Honduras", "Hungary", "Iceland", "India", "Ireland", "Israel", "Italy", "Jamaica", "Japan", "Kuwait", "Lebanon", "Luxembourg", "Malaysia", "Netherlands", "New Zealand", "Nicaragua", "Norway", "Panama", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Korea Republic of", "Romania", "Russian Federation", "Saudi Arabia", "Singapore", "Slovakia", "Spain", "Sweden", "Switzerland", "Thailand", "Trinidad and Tobago", "Turkey", "Ukraine", "United Arab Emirates", "United Kingdom of Great Britain and Northern Ireland", "Uruguay", "Venezuela (Bolivarian Republic of)", "Viet Nam")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 47$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Bahamas", "Bahrain", "Barbados", "Belgium", "Bolivia (Plurinational State of)", "Brazil", "Bulgaria", "Canada", "Cayman Islands", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Cyprus", "Czechia", "Denmark", "Dominica", "Dominican Republic", "Ecuador", "El Salvador", "Egypt", "Estonia", "Finland", "France", "Germany", "Greece", "Guatemala", "Honduras", "Hungary", "Iceland", "India", "Ireland", "Israel", "Italy", "Jamaica", "Japan", "Kuwait", "Lebanon", "Luxembourg", "Malaysia", "Netherlands", "New Zealand", "Nicaragua", "Norway", "Panama", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Korea Republic of", "Romania", "Russian Federation", "Saudi Arabia", "Singapore", "Slovakia", "Spain", "Sweden", "Switzerland", "Thailand", "Trinidad and Tobago", "Turkey", "Ukraine", "United Arab Emirates", "United Kingdom of Great Britain and Northern Ireland", "Uruguay", "Venezuela (Bolivarian Republic of)", "Viet Nam")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 48$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Bahamas", "Bahrain", "Barbados", "Belgium", "Bolivia (Plurinational State of)", "Brazil", "Bulgaria", "Canada", "Cayman Islands", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Cyprus", "Czechia", "Denmark", "Dominica", "Dominican Republic", "Ecuador", "El Salvador", "Egypt", "Estonia", "Finland", "France", "Germany", "Greece", "Guatemala", "Honduras", "Hungary", "Iceland", "India", "Ireland", "Israel", "Italy", "Jamaica", "Japan", "Kuwait", "Lebanon", "Luxembourg", "Malaysia", "Netherlands", "New Zealand", "Nicaragua", "Norway", "Panama", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Korea Republic of", "Romania", "Russian Federation", "Saudi Arabia", "Singapore", "Slovakia", "Spain", "Sweden", "Switzerland", "Thailand", "Trinidad and Tobago", "Turkey", "Ukraine", "United Arab Emirates", "United Kingdom of Great Britain and Northern Ireland", "Uruguay", "Venezuela (Bolivarian Republic of)", "Viet Nam")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 49$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Bahamas", "Bahrain", "Barbados", "Belgium", "Bolivia (Plurinational State of)", "Brazil", "Bulgaria", "Canada", "Cayman Islands", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Cyprus", "Czechia", "Denmark", "Dominica", "Dominican Republic", "Ecuador", "El Salvador", "Egypt", "Estonia", "Finland", "France", "Germany", "Greece", "Guatemala", "Honduras", "Hungary", "Iceland", "India", "Ireland", "Israel", "Italy", "Jamaica", "Japan", "Kuwait", "Lebanon", "Luxembourg", "Malaysia", "Morocco", "Netherlands", "New Zealand", "Nicaragua", "Norway", "Panama", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Korea Republic of", "Romania", "Russian Federation", "Saudi Arabia", "Singapore", "Slovakia", "Spain", "Sweden", "Switzerland", "Thailand", "Trinidad and Tobago", "Turkey", "Ukraine", "United Arab Emirates", "United Kingdom of Great Britain and Northern Ireland", "Uruguay", "Venezuela (Bolivarian Republic of)", "Viet Nam", "Gaza")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 5$"), "Country"] <- c("Austria", "Canada", "Germany", "Israel", "New Zealand", "Spain", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 50$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Bahamas", "Bahrain", "Barbados", "Belgium", "Bolivia (Plurinational State of)", "Brazil", "Virgin Islands (British)", "Bulgaria", "Canada", "Cayman Islands", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Cyprus", "Czechia", "Denmark", "Dominica", "Dominican Republic", "Ecuador", "El Salvador", "Egypt", "Estonia", "Finland", "France", "French Polynesia", "Martinique", "Germany", "Greece", "Guatemala", "Honduras", "Hungary", "Iceland", "India", "Ireland", "Israel", "Italy", "Jamaica", "Japan", "Jordan", "Kuwait", "Lebanon", "Luxembourg", "Malaysia", "Morocco", "Netherlands", "Curaçao", "New Zealand", "Nicaragua", "Norway", "Panama", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Qatar", "Korea Republic of", "Romania", "Russian Federation", "Samoa", "Saudi Arabia", "Singapore", "Slovakia", "Spain", "Sri Lanka", "Sweden", "Switzerland", "Thailand", "Trinidad and Tobago", "Turkey", "Ukraine", "United Arab Emirates", "United Kingdom of Great Britain and Northern Ireland", "Isle of Man", "Jersey", "Uruguay", "Venezuela (Bolivarian Republic of)", "Viet Nam", "Gaza", "Yemen")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 51$"), "Country"] <- c("Mexico", "United States of America", "Argentina", "Australia", "Austria", "Bahamas", "Bahrain", "Barbados", "Belgium", "Bolivia (Plurinational State of)", "Brazil", "Virgin Islands (British)", "Bulgaria", "Canada", "Cayman Islands", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Cyprus", "Czechia", "Denmark", "Dominica", "Dominican Republic", "Ecuador", "El Salvador", "Egypt", "Estonia", "Finland", "France", "French Polynesia", "Martinique", "Germany", "Greece", "Guatemala", "Honduras", "Hungary", "Iceland", "India", "Ireland", "Israel", "Italy", "Jamaica", "Japan", "Jordan", "Kuwait", "Lebanon", "Luxembourg", "Malaysia", "Morocco", "Netherlands", "Curaçao", "Sint Maarten (Dutch part)", "New Zealand", "Nicaragua", "Norway", "Oman", "Panama", "Papua New Guinea", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Qatar", "Korea Republic of", "Romania", "Russian Federation", "Samoa", "Saudi Arabia", "Singapore", "Slovakia", "Spain", "Sri Lanka", "Suriname", "Sweden", "Switzerland", "Thailand", "Trinidad and Tobago", "Turkey", "Ukraine", "United Arab Emirates", "United Kingdom of Great Britain and Northern Ireland", "Isle of Man", "Jersey", "Uruguay", "Venezuela (Bolivarian Republic of)", "Viet Nam", "Gaza", "Yemen")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 52$"), "Country"] <- c("Mexico", "United States of America", "Algeria", "Argentina", "Australia", "Austria", "Bahamas", "Bahrain", "Bangladesh", "Barbados", "Belgium", "Bermuda", "Bolivia (Plurinational State of)", "Brazil", "Brunei Darussalam", "Virgin Islands (British)", "Bulgaria", "Canada", "Cayman Islands", "China", "Colombia", "Costa Rica", "Chile", "Cuba", "Cyprus", "Czechia", "Denmark", "Dominica", "Dominican Republic", "Ecuador", "El Salvador", "Egypt", "Estonia", "Finland", "France", "French Polynesia", "Martinique", "Germany", "Greece", "Guatemala", "Honduras", "Hungary", "Iceland", "India", "Ireland", "Israel", "Italy", "Jamaica", "Japan", "Jordan", "Kuwait", "Lao People's Democratic Republic", "Lebanon", "Luxembourg", "Malaysia", "Morocco", "Netherlands", "Curaçao", "Sint Maarten (Dutch part)", "New Zealand", "Nicaragua", "Norway", "Oman", "Panama", "Papua New Guinea", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Qatar", "Korea Republic of", "Romania", "Russian Federation", "Samoa", "Saudi Arabia", "Singapore", "Slovakia", "South Africa", "Spain", "Sri Lanka", "Suriname", "Sweden", "Switzerland", "Thailand", "Trinidad and Tobago", "Turkey", "Ukraine", "United Arab Emirates", "United Kingdom of Great Britain and Northern Ireland", "Isle of Man", "Jersey", "Uruguay", "Venezuela (Bolivarian Republic of)", "Viet Nam", "Gaza", "Yemen")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 53$"), "Country"] <- c("Mexico", "United States of America", "Algeria", "Argentina", "Australia", "Austria", "Antigua and Barbuda", "Bahamas", "Bahrain", "Bangladesh", "Barbados", "Belgium", "Bermuda", "Bolivia (Plurinational State of)", "Brazil", "Brunei Darussalam", "Virgin Islands (British)", "Bulgaria", "Canada", "Cabo Verde", "Cayman Islands", "China", "Colombia", "Côte d'Ivoire", "Costa Rica", "Chile", "Cuba", "Cyprus", "Czechia", "Denmark", "Dominica", "Dominican Republic", "Ecuador", "El Salvador", "Egypt", "Estonia", "Ethiopia", "Fiji", "Finland", "France", "French Polynesia", "Martinique", "Germany", "Greece", "Guatemala", "Honduras", "Hungary", "Iceland", "India", "Ireland", "Israel", "Italy", "Jamaica", "Japan", "Jordan", "Kuwait", "Lao People's Democratic Republic", "Latvia", "Lebanon", "Luxembourg", "Malaysia", "Montenegro", "Morocco", "Netherlands", "Curaçao", "Sint Maarten (Dutch part)", "New Zealand", "Nicaragua", "Norway", "Oman", "Panama", "Papua New Guinea", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Qatar", "Korea Republic of", "Romania", "Russian Federation", "Samoa", "Saudi Arabia", "Singapore", "Slovakia", "South Africa", "Spain", "Sri Lanka", "Suriname", "Sweden", "Switzerland", "Thailand", "Trinidad and Tobago", "Tunisia", "Turkey", "Ukraine", "United Arab Emirates", "United Kingdom of Great Britain and Northern Ireland", "Isle of Man", "Jersey", "Uruguay", "Vanuatu", "Venezuela (Bolivarian Republic of)", "Viet Nam", "Gaza", "Yemen")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 54$"), "Country"] <- c("Mexico", "United States of America", "Algeria", "Argentina", "Australia", "Austria", "Antigua and Barbuda", "Bahamas", "Bahrain", "Bangladesh", "Barbados", "Belgium", "Bermuda", "Bolivia (Plurinational State of)", "Brazil", "Brunei Darussalam", "Virgin Islands (British)", "Bulgaria", "Canada", "Cabo Verde", "Cambodia", "Cayman Islands", "China", "Colombia", "Côte d'Ivoire", "Costa Rica", "Chile", "Cuba", "Cyprus", "Czechia", "Denmark", "Dominica", "Dominican Republic", "Ecuador", "El Salvador", "Egypt", "Estonia", "Ethiopia", "Fiji", "Finland", "France", "French Polynesia", "Martinique", "Germany", "Greece", "Guatemala", "Honduras", "Hungary", "Iceland", "India", "Iran (Islamic Republic of)", "Ireland", "Israel", "Italy", "Jamaica", "Japan", "Jordan", "Kuwait", "Lao People's Democratic Republic", "Latvia", "Lebanon", "Luxembourg", "Malaysia", "Montenegro", "Morocco", "Netherlands", "Curaçao", "Sint Maarten (Dutch part)", "New Zealand", "Nicaragua", "Norway", "Oman", "Panama", "Papua New Guinea", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Qatar", "Korea Republic of", "Romania", "Russian Federation", "Samoa", "Saudi Arabia", "Serbia", "Singapore", "Slovakia", "South Africa", "Spain", "Sri Lanka", "Suriname", "Sweden", "Switzerland", "Thailand", "Trinidad and Tobago", "Tunisia", "Turkey", "Ukraine", "United Arab Emirates", "United Kingdom of Great Britain and Northern Ireland", "Guernsey", "Isle of Man", "Jersey", "Uruguay", "Vanuatu", "Venezuela (Bolivarian Republic of)", "Viet Nam", "Gaza", "Yemen")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 55$"), "Country"] <- c("Mexico", "United States of America", "Algeria", "Argentina", "Australia", "Austria", "Antigua and Barbuda", "Bahamas", "Bahrain", "Bangladesh", "Barbados", "Belgium", "Bermuda", "Bolivia (Plurinational State of)", "Brazil", "Brunei Darussalam", "Virgin Islands (British)", "Bulgaria", "Canada", "Cabo Verde", "Cambodia", "Cayman Islands", "China", "Colombia", "Côte d'Ivoire", "Costa Rica", "Chile", "Cuba", "Cyprus", "Czechia", "Denmark", "Dominica", "Dominican Republic", "Ecuador", "El Salvador", "Egypt", "Estonia", "Ethiopia", "Fiji", "Finland", "France", "French Polynesia", "Martinique", "Germany", "Greece", "Guatemala", "Honduras", "Hungary", "Iceland", "India", "Iran (Islamic Republic of)", "Iraq", "Ireland", "Israel", "Italy", "Jamaica", "Japan", "Jordan", "Kuwait", "Lao People's Democratic Republic", "Latvia", "Lebanon", "Lithuania", "Luxembourg", "Malaysia", "Monaco", "Montenegro", "Morocco", "Nepal", "Netherlands", "Curaçao", "Sint Maarten (Dutch part)", "New Zealand", "Nicaragua", "Norway", "Oman", "Panama", "Papua New Guinea", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Qatar", "Korea Republic of", "Romania", "Russian Federation", "Samoa", "Saudi Arabia", "Serbia", "Singapore", "Slovakia", "South Africa", "Spain", "Sri Lanka", "Suriname", "Sweden", "Switzerland", "Thailand", "Trinidad and Tobago", "Tunisia", "Turkey", "Ukraine", "United Arab Emirates", "United Kingdom of Great Britain and Northern Ireland", "Guernsey", "Isle of Man", "Jersey", "Uruguay", "Vanuatu", "Venezuela (Bolivarian Republic of)", "Viet Nam", "Gaza", "Yemen")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 6$"), "Country"] <- c("Mexico", "United States of America", "Austria", "Canada", "Germany", "Israel", "Netherlands", "New Zealand", "Spain", "Switzerland", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N1\\) - update 8.1$"), "Country"] <- c("Mexico", "United States of America", "Austria", "Canada", "Hong Kong", "Denmark", "Germany", "Israel", "Netherlands", "New Zealand", "Spain", "Switzerland", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza A\\(H1N2\\) variant virus$"), "Country"] <- "Brazil"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Measles$") & DONsdf9$Date == "2020-01-10", "Country"] <- "Gaza"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Measles – European Region$"), "Country"] <- c("Ukraine", "Serbia", "Israel", "France", "Russian Federation", "Georgia", "Greece")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Measles – Global situation$"), "Country"] <- c("American Samoa", "Bangladesh", "Brazil", "Chad", "Colombia", "Congo Democratic Republic of the", "Fiji", "Georgia", "Guinea", "Iraq", "Kazakhstan", "Kyrgyzstan", "Lebanon", "Madagascar", "Myanmar", "Nigeria", "Pakistan", "Philippines", "Russian Federation", "Somalia", "Sudan", "Tunisia", "Turkey", "Ukraine", "United States of America", "Venezuela (Bolivarian Republic of)", "Viet Nam", "Yemen")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Measles – Pacific Island Countries and Areas$"), "Country"] <- c("Tonga", "Fiji", "Samoa")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Measles – The Americas$"), "Country"] <- c("Brazil", "Canada", "Mexico", "United States of America")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Measles – Western Pacific Region$"), "Country"] <- c("Australia", "China", "Hong Kong", "Macao", "Japan", "Malaysia", "New Zealand", "Philippines", "Korea Republic of") 
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Measles – WHO European Region$"), "Country"] <- c("Kyrgyzstan", "Bosnia and Herzegovina", "Croatia", "Georgia", "Germany", "Italy", "Kazakhstan", "Russian Federation", "Serbia") 
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Measles outbreaks: Regions of the Americas, Europe and Africa$"), "Country"] <- c("France", "Germany", "Kyrgyzstan", "Romania", "North Macedonia", "United Kingdom of Great Britain and Northern Ireland", "Congo Democratic Republic of the", "Nigeria", "Zambia", "Ethiopia", "United States of America", "Canada", "Ecuador", "Brazil", "Colombia", "Mexico", "Chile")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Meningococcal disease in the African Meningitis Belt$"), "Country"] <- c("Burkina Faso", "Central African Republic", "Congo Democratic Republic of the", "Côte d'Ivoire", "Benin", "Ethiopia", "Ghana", "Mali", "Niger", "Nigeria", "Togo")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Meningococcal disease in the African Meningitis Belt, epidemic season 2006$"), "Country"] <- c("Burkina Faso", "Côte d'Ivoire", "Niger", "Kenya", "Mali", "Sudan", "Uganda")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Meningococcal disease: 2013 epidemic season in the African Meningitis Belt$"), "Country"] <- c("Guinea", "South Sudan", "Benin", "Burkina Faso", "Nigeria")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Meningococcal disease: situation in the African Meningitis Belt$") & DONsdf9$Date == "2012-05-24", "Country"] <- c("Benin", "Burkina Faso", "Chad", "Central African Republic", "Côte d'Ivoire", "Gambia", "Ghana", "Mali", "Nigeria", "Sudan")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Meningococcal disease: situation in the African Meningitis Belt$") & DONsdf9$Date == "2012-03-23", "Country"] <- c("Benin", "Burkina Faso", "Chad", "Ghana", "Côte d'Ivoire")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Meningococcal Disease: situation in the African Meningitis Belt$") & DONsdf9$Date == "2009-03-25", "Country"] <- c("Niger", "Nigeria")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome- coronavirus - update$"), "Country"] <- c("Jordan", "Saudi Arabia", "United Arab Emirates", "Qatar", "France", "Germany", "Tunisia", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\)$"), "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2014-02-04", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2014-01-27", "Country"] <- "Jordan"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2014-01-03", "Country"] <- "United Arab Emirates"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-12-31", "Country"] <- c("Saudi Arabia", "United Arab Emirates")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-12-27", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-12-22", "Country"] <- "United Arab Emirates"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-12-17", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-12-02", "Country"] <- "United Arab Emirates"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-11-18", "Country"] <- "Kuwait"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-11-15", "Country"] <- "United Arab Emirates"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-11-11", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-11-10", "Country"] <- "Qatar"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-11-07", "Country"] <- "Spain"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-11-04", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-10-31", "Country"] <- "Oman"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-10-29", "Country"] <- "Qatar"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-10-18", "Country"] <- "Qatar"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-10-14", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-10-04", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-09-20", "Country"] <- "Italy"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-09-19", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-09-07", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-09-06", "Country"] <- "Qatar"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-08-30", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-08-29", "Country"] <- "Qatar"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-08-28", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-08-01", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-07-29", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-07-21", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-07-19", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-07-18", "Country"] <- c("Saudi Arabia", "United Arab Emirates")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-07-13", "Country"] <- "United Arab Emirates"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-07-11", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-07-07", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-07-05", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-06-26", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-06-23", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-06-22", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-06-17", "Country"] <- c("Jordan", "Qatar", "Saudi Arabia", "United Arab Emirates", "France", "Germany", "Italy", "Tunisia", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-06-15", "Country"] <- c("Jordan", "Qatar", "Saudi Arabia", "United Arab Emirates", "France", "Germany", "Italy", "Tunisia", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-06-14", "Country"] <- c("Jordan", "Qatar", "Saudi Arabia", "United Arab Emirates", "France", "Germany", "Italy", "Tunisia", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-06-07", "Country"] <- c("Jordan", "Qatar", "Saudi Arabia", "United Arab Emirates", "France", "Germany", "Italy", "Tunisia", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-06-05", "Country"] <- c("Jordan", "Qatar", "Saudi Arabia", "United Arab Emirates", "France", "Germany", "Italy", "Tunisia", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-06-02", "Country"] <- c("Jordan", "Qatar", "Saudi Arabia", "United Arab Emirates", "France", "Germany", "Italy", "Tunisia", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-06-01", "Country"] <- c("Jordan", "Qatar", "Saudi Arabia", "United Arab Emirates", "France", "Germany", "Italy", "Tunisia", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-05-31", "Country"] <- c("Jordan", "Qatar", "Saudi Arabia", "United Arab Emirates", "France", "Germany", "Italy", "Tunisia", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2016-04-25", "Country"] <- "Bahrain"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-07-23", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-07-14", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-07-04", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-07-02", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-06-26", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-06-25", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-06-16", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-06-14", "Country"] <- "Algeria"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-06-13", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-06-11", "Country"] <- "Iran (Islamic Republic of)"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-06-04", "Country"] <- "Jordan"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-05-28", "Country"] <- "Jordan"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-05-23", "Country"] <- "United Arab Emirates"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-05-22", "Country"] <- "United States of America"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-05-16", "Country"] <- "Netherlands"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-05-15", "Country"] <- c("Netherlands", "United States of America", "Jordan", "United Arab Emirates", "Lebanon")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-05-14", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-05-07", "Country"] <- "Yemen"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Link == "https://www.who.int/emergencies/disease-outbreak-news/item/2014_05_07_mers_jordan-en", "Country"] <- "Jordan"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Link == "https://www.who.int/emergencies/disease-outbreak-news/item/2014_05_05_mers_jordan-en", "Country"] <- "Jordan"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Link == "https://www.who.int/emergencies/disease-outbreak-news/item/2014_05_05_mers-en", "Country"] <- "United States of America"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-05-01", "Country"] <- "Egypt"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-04-26", "Country"] <- "United Arab Emirates"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-04-24", "Country"] <- "Jordan"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-04-23", "Country"] <- "United Arab Emirates"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-04-20", "Country"] <- "Greece"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-04-17", "Country"] <- "Malaysia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-04-16", "Country"] <- "United Arab Emirates"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-04-14", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-04-11", "Country"] <- "Jordan"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-04-10", "Country"] <- c("Saudi Arabia", "United Arab Emirates")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-03-27", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-03-26", "Country"] <- "United Arab Emirates"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-03-25", "Country"] <- "United Arab Emirates"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-03-20", "Country"] <- "United Arab Emirates"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-03-18", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-03-12", "Country"] <- c("Saudi Arabia", "United Arab Emirates")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-02-28", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – update$") & DONsdf9$Date == "2014-02-07", "Country"] <- "United Arab Emirates"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) - update$") & DONsdf9$Date == "2013-11-29", "Country"] <- "Qatar"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection - update$") & DONsdf9$Date == "2013-05-22", "Country"] <- c("Jordan", "Qatar", "Saudi Arabia", "United Arab Emirates", "France", "Germany", "Tunisia", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection - update$") & DONsdf9$Date == "2013-05-18", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection - update$") & DONsdf9$Date == "2013-05-15", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection - update$") & DONsdf9$Date == "2013-05-14", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection - update$") & DONsdf9$Date == "2013-05-12", "Country"] <- c("France", "Saudi Arabia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection - update$") & DONsdf9$Date == "2013-05-09", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection - update$") & DONsdf9$Date == "2013-05-08", "Country"] <- "France"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection - update$") & DONsdf9$Date == "2013-05-06", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection - update$") & DONsdf9$Date == "2013-05-03", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection - update$") & DONsdf9$Date == "2013-05-02", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection - update$") & DONsdf9$Date == "2013-03-26", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection - update$") & DONsdf9$Date == "2013-03-23", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection - update$") & DONsdf9$Date == "2013-03-12", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection - update$") & DONsdf9$Date == "2013-03-06", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection - update$") & DONsdf9$Date == "2013-02-21", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection - update \\(Middle East respiratory syndrome- coronavirus\\)$") & DONsdf9$Date == "2013-05-23", "Country"] <- "Saudi Arabia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection – update$") & DONsdf9$Date == "2013-02-16", "Country"] <- "United Kingdom of Great Britain and Northern Ireland"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection – update$") & DONsdf9$Date == "2013-02-13", "Country"] <- "United Kingdom of Great Britain and Northern Ireland"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Novel coronavirus infection – update$") & DONsdf9$Date == "2013-02-11", "Country"] <- "United Kingdom of Great Britain and Northern Ireland"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 100$"), "Country"] <- c("Jamaica", "Dominican Republic", "Nicaragua", "Honduras", "Guatemala", "Colombia", "Bolivia (Plurinational State of)", "Peru", "Bangladesh", "Malaysia", "Singapore", "India", "China", "Hong Kong", "Ghana", "Senegal", "Cameroon", "Russian Federation", "Italy")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 101$"), "Country"] <- c("Cuba", "Mexico", "Dominican Republic", "Nicaragua", "Honduras", "Guatemala", "Panama", "Bolivia (Plurinational State of)", "Bangladesh", "Malaysia", "Singapore", "Thailand", "Cambodia", "Philippines", "China", "Hong Kong", "Korea Republic of", "Australia", "New Zealand", "Angola", "Rwanda", "Ghana")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 102$"), "Country"] <- c("Cuba", "Costa Rica", "Peru", "Colombia", "Brazil", "Bolivia (Plurinational State of)", "Bangladesh", "Malaysia", "Singapore", "Cameroon", "Angola", "Rwanda", "Ghana")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 103$"), "Country"] <- c("Cuba", "Costa Rica", "Peru", "Colombia", "Brazil", "Bolivia (Plurinational State of)", "Bangladesh", "Malaysia", "Singapore", "Cameroon", "Angola", "Rwanda", "Ghana")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 104$"), "Country"] <- c("Cuba", "Costa Rica", "Chile", "Peru", "Colombia", "Brazil", "Bolivia (Plurinational State of)", "Venezuela (Bolivarian Republic of)", "Uruguay", "Bangladesh", "Malaysia", "Singapore", "Cameroon", "Angola", "Rwanda", "Ghana", "Kenya", "Tanzania United Republic of", "Australia", "New Zealand")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 105$"), "Country"] <- c("Cuba", "Costa Rica", "Chile", "Peru", "Colombia", "Brazil", "Bolivia (Plurinational State of)", "Venezuela (Bolivarian Republic of)", "Uruguay", "Bhutan", "Bangladesh", "Malaysia", "Singapore", "Cameroon", "Angola", "Rwanda", "Ghana", "Kenya", "Tanzania United Republic of", "Australia", "New Zealand")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 106$"), "Country"] <- c("Cuba", "Costa Rica", "Chile", "Peru", "Colombia", "Brazil", "Bolivia (Plurinational State of)", "El Salvador", "Venezuela (Bolivarian Republic of)", "Uruguay", "Bhutan", "Bangladesh", "China", "Hong Kong", "Malaysia", "Singapore", "Cameroon", "Angola", "Rwanda", "Ghana", "Kenya", "Tanzania United Republic of", "Australia", "New Zealand", "South Africa")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 108$"), "Country"] <- c("Cuba", "Costa Rica", "Chile", "Peru", "Colombia", "Brazil", "Bolivia (Plurinational State of)", "El Salvador", "Nicaragua", "Venezuela (Bolivarian Republic of)", "Uruguay", "Bhutan", "Bangladesh", "China", "Hong Kong", "Malaysia", "Korea Republic of", "Singapore", "Cameroon", "Angola", "Rwanda", "Ghana", "Kenya", "Tanzania United Republic of", "Australia", "New Zealand", "South Africa")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 109$"), "Country"] <- c("Argentina", "Cuba", "Costa Rica", "Chile", "Peru", "Colombia", "Brazil", "Bolivia (Plurinational State of)", "El Salvador", "Nicaragua", "Venezuela (Bolivarian Republic of)", "Uruguay", "Bhutan", "Bangladesh", "China", "Hong Kong", "India", "Malaysia", "Korea Republic of", "Singapore", "Thailand", "Cameroon", "Angola", "Rwanda", "Ghana", "Kenya", "Tanzania United Republic of", "Australia", "New Zealand", "South Africa")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 110$"), "Country"] <- c("Argentina", "Cuba", "Costa Rica", "Chile", "Peru", "Colombia", "Brazil", "Bolivia (Plurinational State of)", "El Salvador", "Nicaragua", "Venezuela (Bolivarian Republic of)", "Uruguay", "Bhutan", "Bangladesh", "Cambodia", "China", "Hong Kong", "India", "Malaysia", "Korea Republic of", "Singapore", "Thailand", "Cameroon", "Angola", "Rwanda", "Ghana", "Kenya", "Tanzania United Republic of", "Australia", "New Zealand", "South Africa")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 111$"), "Country"] <- c("Argentina", "Cuba", "Costa Rica", "Chile", "Peru", "Colombia", "Brazil", "Bolivia (Plurinational State of)", "El Salvador", "Nicaragua", "Venezuela (Bolivarian Republic of)", "Uruguay", "Bhutan", "Bangladesh", "Cambodia", "China", "Hong Kong", "India", "Malaysia", "Korea Republic of", "Singapore", "Thailand", "Cameroon", "Angola", "Rwanda", "Ghana", "Kenya", "Tanzania United Republic of", "Australia", "New Zealand", "South Africa")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 112$"), "Country"] <- c("Argentina", "Cuba", "Costa Rica", "Chile", "Peru", "Colombia", "Brazil", "Bolivia (Plurinational State of)", "El Salvador", "Nicaragua", "Venezuela (Bolivarian Republic of)", "Uruguay", "Bhutan", "Bangladesh", "Cambodia", "China", "Hong Kong", "India", "Malaysia", "Korea Republic of", "Singapore", "Thailand", "Cameroon", "Angola", "Rwanda", "Ghana", "Kenya", "Tanzania United Republic of", "Australia", "New Zealand", "South Africa")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 56$"), "Country"] <- c("Algeria", "Antigua and Barbuda", "Argentina", "Australia", "Austria", "Bahamas", "Bahrain", "Bangladesh", "Barbados", "Belgium", "Bermuda", "Bolivia (Plurinational State of)", "Brazil", "Virgin Islands (British)", "Brunei Darussalam", "Bulgaria", "Cambodia", "Canada", "Cabo Verde", "Cayman Islands", "Chile", "China", "Colombia", "Costa Rica", "Côte d'Ivoire", "Cuba", "Cyprus", "Czechia", "Denmark", "Dominica", "Dominican Republic", "Ecuador", "Egypt", "El Salvador", "Estonia", "Ethiopia", "Fiji", "Finland", "France", "French Polynesia", "Martinique", "New Caledonia", "Germany", "Greece", "Guatemala", "Honduras", "Hungary", "Iceland", "India", "Indonesia", "Iran (Islamic Republic of)", "Iraq", "Ireland", "Israel", "Italy", "Jamaica", "Japan", "Jordan", "Kenya", "Korea Republic of", "Kuwait", "Lao People's Democratic Republic", "Latvia", "Lebanon", "Lithuania", "Luxembourg", "Malaysia", "Mauritius", "Mexico", "Montenegro", "Morocco", "Myanmar", "Nepal", "Netherlands", "Curaçao", "Sint Maarten (Dutch part)", "New Zealand", "Nicaragua", "Norway", "Oman", "Panama", "Papua New Guinea", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Qatar", "Romania", "Russian Federation", "Saint Lucia", "Samoa", "Saudi Arabia", "Serbia", "Singapore", "Slovakia", "Slovenia", "South Africa", "Spain", "Sri Lanka", "Suriname", "Sweden", "Switzerland", "Thailand", "Trinidad and Tobago", "Tunisia", "Turkey", "Ukraine", "United Arab Emirates", "United Kingdom of Great Britain and Northern Ireland", "Guernsey", "Isle of Man", "Jersey", "United States of America", "Uruguay", "Vanuatu", "Venezuela (Bolivarian Republic of)", "Viet Nam", "Gaza", "Yemen")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 57$"), "Country"] <- c("Algeria", "Antigua and Barbuda", "Argentina", "Australia", "Austria", "Bahamas", "Bahrain", "Bangladesh", "Barbados", "Belgium", "Bermuda", "Bolivia (Plurinational State of)", "Bosnia and Herzegovina", "Brazil", "Virgin Islands (British)", "Brunei Darussalam", "Bulgaria", "Cambodia", "Canada", "Cabo Verde", "Cayman Islands", "Chile", "China", "Colombia", "Costa Rica", "Côte d'Ivoire", "Cuba", "Cyprus", "Czechia", "Denmark", "Dominica", "Dominican Republic", "Ecuador", "Egypt", "El Salvador", "Estonia", "Ethiopia", "Fiji", "Finland", "France", "French Polynesia", "Martinique", "New Caledonia", "Germany", "Greece", "Guatemala", "Honduras", "Hungary", "Iceland", "India", "Indonesia", "Iran (Islamic Republic of)", "Iraq", "Ireland", "Israel", "Italy", "Jamaica", "Japan", "Jordan", "Kenya", "Korea Republic of", "Kuwait", "Lao People's Democratic Republic", "Latvia", "Lebanon", "Lithuania", "Luxembourg", "Malaysia", "Mauritius", "Mexico", "Montenegro", "Morocco", "Myanmar", "Nepal", "Netherlands", "Aruba", "Curaçao", "Sint Maarten (Dutch part)", "New Zealand", "Nicaragua", "Norway", "Oman", "Panama", "Papua New Guinea", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Qatar", "Romania", "Russian Federation", "Saint Lucia", "Samoa", "Saudi Arabia", "Serbia", "Singapore", "Slovakia", "Slovenia", "South Africa", "Spain", "Sri Lanka", "Suriname", "Sweden", "Switzerland", "Thailand", "Trinidad and Tobago", "Tunisia", "Turkey", "Uganda", "Ukraine", "United Arab Emirates", "United Kingdom of Great Britain and Northern Ireland", "Guernsey", "Isle of Man", "Jersey", "United States of America", "Uruguay", "Vanuatu", "Venezuela (Bolivarian Republic of)", "Viet Nam", "Gaza", "Yemen")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 58$"), "Country"] <- c("Algeria", "Antigua and Barbuda", "Argentina", "Australia", "Austria", "Bahamas", "Bahrain", "Bangladesh", "Barbados", "Belgium", "Bermuda", "Bolivia (Plurinational State of)", "Bosnia and Herzegovina", "Brazil", "Virgin Islands (British)", "Brunei Darussalam", "Bulgaria", "Cambodia", "Canada", "Cabo Verde", "Cayman Islands", "Chile", "China", "Colombia", "Costa Rica", "Côte d'Ivoire", "Cook Islands", "Croatia", "Cuba", "Cyprus", "Czechia", "Denmark", "Dominica", "Dominican Republic", "Ecuador", "Egypt", "El Salvador", "Estonia", "Ethiopia", "Fiji", "Finland", "France", "French Polynesia", "Guadeloupe", "Martinique", "New Caledonia", "Saint Martin (French part)", "Germany", "Greece", "Guatemala", "Guyana", "Honduras", "Hungary", "Iceland", "India", "Indonesia", "Iran (Islamic Republic of)", "Iraq", "Ireland", "Israel", "Italy", "Jamaica", "Japan", "Jordan", "Kenya", "Korea Republic of", "Kuwait", "Lao People's Democratic Republic", "Latvia", "Lebanon", "Libya", "Lithuania", "Luxembourg", "Malaysia", "Mauritius", "Mexico", "Montenegro", "Morocco", "Myanmar", "Nepal", "Netherlands", "Aruba", "Curaçao", "Sint Maarten (Dutch part)", "New Zealand", "Nicaragua", "Norway", "Oman", "Panama", "Papua New Guinea", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Qatar", "Romania", "Russian Federation", "Saint Lucia", "Samoa", "Saudi Arabia", "Serbia", "Singapore", "Slovakia", "Slovenia", "South Africa", "Spain", "Sri Lanka", "Suriname", "Sweden", "Switzerland", "Syrian Arab Republic", "Thailand", "North Macedonia", "Trinidad and Tobago", "Tunisia", "Turkey", "Uganda", "Ukraine", "United Arab Emirates", "United Kingdom of Great Britain and Northern Ireland", "Guernsey", "Isle of Man", "Jersey", "United States of America", "Puerto Rico", "Virgin Islands (U.S.)", "Uruguay", "Vanuatu", "Venezuela (Bolivarian Republic of)", "Viet Nam", "Gaza", "Yemen")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 59$"), "Country"] <- c("Afghanistan", "Andorra", "Belize", "Bhutan", "Botswana", "Réunion", "Haiti", "Marshall Islands", "Micronesia (Federated States of)", "Namibia", "Bonaire Sint Eustatius and Saba", "Saint Kitts and Nevis", "Saint Vincent and the Grenadines", "Seychelles", "Solomon Islands", "Sudan", "Tonga", "Turks and Caicos Islands", "Tanzania United Republic of", "American Samoa", "Guam")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 60$"), "Country"] <- c("Azerbaijan", "Gabon", "Grenada", "Kazakhstan", "Moldova Republic of", "Monaco", "Nauru", "Eswatini", "Suriname")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 61$"), "Country"] <- c("Timor-Leste", "Pakistan", "Kiribati", "Maldives", "French Guiana", "Falkland Islands (Malvinas)", "Wallis and Futuna")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 62 \\(revised 21 August 2009\\)$"), "Country"] <- c("Ghana", "Zambia", "Tuvalu")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 63$"), "Country"] <- c("Cameroon", "Madagascar", "Mozambique")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 64$"), "Country"] <- c("Zimbabwe", "Djibouti")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 65$"), "Country"] <- c("Lesotho", "Angola")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 66$"), "Country"] <- "Malawi"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 69$"), "Country"] <- "Tajikistan"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 71$"), "Country"] <- c("Mongolia", "Rwanda", "Sao Tome and Principe", "Iceland", "Sudan", "Trinidad and Tobago")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 73$"), "Country"] <- c("Congo", "Afghanistan", "Croatia", "Mongolia", "Tanzania United Republic of", "Ukraine")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 74$"), "Country"] <- c("Somalia", "Nigeria", "Burundi", "Saint Lucia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 75$"), "Country"] <- c("Sri Lanka", "Pakistan", "Slovenia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 76$"), "Country"] <- c("Armenia", "North Macedonia", "Switzerland", "Poland", "Tunisia", "Morocco", "Madagascar")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 77$"), "Country"] <- c("Romania", "Slovakia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 78$"), "Country"] <- c("Austria", "Lithuania", "Latvia", "United Arab Emirates", "Korea (Democratic People's Republic of)")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 79$"), "Country"] <- c("Bahamas", "Bosnia and Herzegovina", "Estonia", "Montenegro", "Libya")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 80$"), "Country"] <- c("Georgia", "Albania")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 81$"), "Country"] <- c("Nepal", "Armenia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 83$"), "Country"] <- "Sudan"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 84$"), "Country"] <- "Mali"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 85$"), "Country"] <- c("Cyprus", "Nigeria")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 86$"), "Country"] <- c("Mauritania", "Chad")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 89$"), "Country"] <- "Niger"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Pandemic \\(H1N1\\) 2009 - update 96$"), "Country"] <- c("Sao Tome and Principe", "Guinea")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Polio outbreak in the Middle East - update$"), "Country"] <- "Syrian Arab Republic"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Recent outbreaks of cholera in Africa$"), "Country"] <- c("Burundi", "Cameroon", "Mali", "Mozambique", "South Africa", "Zambia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 45$"), "Country"] <- c("Canada", "China", "Hong Kong", "Taiwan Province of China")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 46$"), "Country"] <- c("China", "Hong Kong")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 48$"), "Country"] <- "Colombia"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 49$"), "Country"] <- c("China", "Hong Kong", "Taiwan Province of China")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 51$"), "Country"] <- c("China", "Hong Kong")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 52$"), "Country"] <- c("China", "Hong Kong", "Taiwan Province of China")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 53$"), "Country"] <- c("China", "Hong Kong", "Taiwan Province of China", "Singapore")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 54$"), "Country"] <- c("China", "Hong Kong", "Taiwan Province of China")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 55$"), "Country"] <- c("China", "Hong Kong", "Taiwan Province of China", "Canada")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 56$"), "Country"] <- c("China", "Hong Kong")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 57$"), "Country"] <- c("China", "Hong Kong", "Taiwan Province of China")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 58$"), "Country"] <- c("China", "Hong Kong")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 59$"), "Country"] <- c("China", "Hong Kong", "Taiwan Province of China")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\)-multi-country outbreak - Update 60$"), "Country"] <- c("China", "Hong Kong", "Taiwan Province of China")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update$"), "Country"] <- c("Singapore", "Thailand", "Canada", "Philippines", "Indonesia", "Germany", "United States of America", "Hong Kong", "Viet Nam")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 12$"), "Country"] <- c("China", "Romania")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 13$"), "Country"] <- c("Canada", "Taiwan Province of China", "Singapore", "Hong Kong", "United States of America")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 14$"), "Country"] <- c("Canada", "Hong Kong", "United States of America")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 15$"), "Country"] <- c("Canada", "Hong Kong", "Germany", "Switzerland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 16$"), "Country"] <- c("China", "Hong Kong", "Canada", "Taiwan Province of China", "Italy", "Singapore", "Thailand", "United States of America", "Australia", "Belgium")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 18$"), "Country"] <- c("China", "Hong Kong", "Taiwan Province of China", "Singapore")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 20$"), "Country"] <- c("Canada", "Hong Kong", "Taiwan Province of China", "France", "Singapore", "United States of America", "Viet Nam", "Brazil")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 21$"), "Country"] <- c("Canada", "China", "Hong Kong", "Taiwan Province of China", "Singapore", "United States of America")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 22$"), "Country"] <- c("Canada", "Hong Kong", "Taiwan Province of China", "Singapore", "United Kingdom of Great Britain and Northern Ireland", "United States of America", "Malaysia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 23$"), "Country"] <- c("China", "Canada", "Hong Kong", "Taiwan Province of China", "Singapore", "Viet Nam")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 24$"), "Country"] <- c("China", "Canada", "Hong Kong", "France", "Singapore", "United States of America")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 25$"), "Country"] <- c("China", "Canada", "Hong Kong", "Singapore", "United States of America", "Viet Nam")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 26$"), "Country"] <- c("Brazil", "China", "Canada", "Hong Kong", "Germany", "Singapore", "United States of America", "Malaysia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 27$"), "Country"] <- c("China", "Canada", "Hong Kong", "Viet Nam", "Singapore")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 28$"), "Country"] <- c("Canada", "Hong Kong", "Taiwan Province of China", "Thailand", "Singapore", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 29$"), "Country"] <- c("China", "Hong Kong")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 30$"), "Country"] <- c("Singapore", "Hong Kong")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 32$"), "Country"] <- c("China", "Hong Kong")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 33$"), "Country"] <- c("China", "Hong Kong", "India")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 34$"), "Country"] <- "Hong Kong"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 35$"), "Country"] <- "China"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - multi-country outbreak - Update 36$"), "Country"] <- c("China", "Hong Kong")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - Multi-country outbreak - Update 41$"), "Country"] <- c("China", "Hong Kong", "Singapore")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - Multi-country outbreak - Update 42$"), "Country"] <- c("Canada", "China", "Hong Kong", "Singapore")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - Multi-country outbreak - Update 43$"), "Country"] <- c("China", "Hong Kong", "Taiwan Province of China")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - Multi-country outbreak - Update 44$"), "Country"] <- c("China", "Hong Kong", "Taiwan Province of China", "Singapore", "Poland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - Multi-country outbreak Update 38$"), "Country"] <- c("Canada", "China", "Hong Kong", "Singapore", "Bulgaria")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - Multi-country outbreak Update 39$"), "Country"] <- c("China", "Hong Kong")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) - Multi-country outbreak Update 40$"), "Country"] <- c("Canada", "China", "Hong Kong", "Singapore", "Philippines")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) multi-country outbreak - Update 10$"), "Country"] <- "China"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) multi-country outbreak - Update 3$"), "Country"] <- c("Canada", "China", "Taiwan Province of China", "Germany", "Hong Kong", "Singapore", "Slovenia", "Thailand", "Viet Nam", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) multi-country outbreak - Update 4$"), "Country"] <- c("Canada", "China", "Spain", "Germany", "Singapore", "Slovenia", "Thailand", "Viet Nam", "United Kingdom of Great Britain and Northern Ireland", "United States of America")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) multi-country outbreak - Update 5$"), "Country"] <- c("Canada", "Singapore", "Hong Kong", "Taiwan Province of China", "Viet Nam", "United Kingdom of Great Britain and Northern Ireland", "Switzerland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) multi-country outbreak - Update 6$"), "Country"] <- "China"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Severe Acute Respiratory Syndrome \\(SARS\\) multi-country outbreak - Update 8$"), "Country"] <- c("Canada", "Singapore", "Hong Kong", "Viet Nam", "United States of America")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Seychelles – Suspected Plague \\(Ex- Madagascar\\)$"), "Country"] <- "Seychelles"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Swine influenza - update 3$"), "Country"] <- c("Canada", "United States of America", "Mexico", "Spain")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Swine influenza - update 4$"), "Country"] <- c("Canada", "United States of America", "Mexico", "Spain", "New Zealand", "Israel")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Update 73 - No new deaths, but vigilance needed for imported cases$"), "Country"] <- c("Canada", "Hong Kong", "Taiwan Province of China", "Germany", "United States of America")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Update 74 - Global decline in cases and deaths continues$"), "Country"] <- c("Canada", "Taiwan Province of China", "China", "Hong Kong") 
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Update on polio in central Africa$"), "Country"] <- c("Equatorial Guinea", "Cameroon", "Brazil")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Update on polio in central Africa - polio confirmed in Equatorial Guinea, linked to outbreak in Cameroon$"), "Country"] <- c("Equatorial Guinea", "Cameroon")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^West Nile Virus Infection \\(WNV\\) in Europe$"), "Country"] <- c("Albania", "Greece", "Israel", "Romania", "Russian Federation")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Widespread human influenza activity persists in northern hemisphere - update 5$"), "Country"] <- c("Canada", "Czechia", "Denmark", "France", "Italy", "Norway", "Portugal", "Russian Federation", "Spain", "Switzerland", "Ukraine", "United Kingdom of Great Britain and Northern Ireland", "United States of America", "Austria", "Chile", "Hong Kong", "Hungary", "Iceland", "India", "Japan", "Latvia", "Thailand", "Tunisia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Wild poliovirus in the Horn of Africa – update$"), "Country"] <- c("South Sudan", "Somalia", "Kenya", "Ethiopia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Yellow Fever - West and Central Africa$"), "Country"] <- c("Cameroon", "Chad", "Central African Republic", "Côte d'Ivoire", "Congo Democratic Republic of the", "Ghana", "Niger", "Nigeria", "Congo")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Zika virus infection – Region of the Americas$"), "Country"] <- c("Costa Rica", "Curaçao", "Jamaica", "Nicaragua")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Poliovirus in South Sudan and Madagascar$"), "Country"] <- c("Madagascar", "South Sudan")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Poliomyelitis in Nigeria and West/Central Africa$"), "Country"] <- c("Nigeria", "Benin", "Niger", "Côte d'Ivoire", "Ghana", "Guinea", "Togo", "Chad")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1996 - Ebola infection in Côte d'Ivoire/Liberia$"), "Country"] <- c("Côte d'Ivoire", "Liberia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1996 - Dengue/dengue haemorrhagic fever in the Philippines and Malaysia$"), "Country"] <- c("Philippines", "Malaysia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Lassa Fever – Benin, Togo and Burkina Faso$"), "Country"] <- c("Benin", "Togo", "Burkina Faso")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1996 - Cholera in Rwanda and Zaire$"), "Country"] <- c("Rwanda", "Congo Democratic Republic of the")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Avian influenza – situation in Viet Nam and Cambodia – update 12$"), "Country"] <- c("Viet Nam", "Cambodia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Avian influenza – situation in Viet Nam and Cambodia - update 8$"), "Country"] <- c("Viet Nam", "Cambodia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Avian influenza A\\(H5N1\\) - update 22: First data on patients from Viet Nam, Clinical data from Hong Kong 1997, Susceptibility of H5N1 viruses to antiviral drugs$"), "Country"] <- c("Viet Nam", "Hong Kong", "Thailand")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Avian influenza A\\(H5N1\\) - update 18: FAO/OIE/WHO Technical Consultation on the Control of Avian Influenza, Situation \\(human\\) in Thailand and Viet Nam$"), "Country"] <- c("Viet Nam", "Thailand")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2000 - Meningococcal disease in France and the United Kingdom$"), "Country"] <- c("France", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2001 - Ebola haemorrhagic fever in Gabon/The Republic of the Congo - Update 10$"), "Country"] <- c("Congo", "Gabon")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2002 - Ebola haemorrhagic fever in Gabon/The Republic of the Congo - Update 21$"), "Country"] <- c("Congo", "Gabon")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2002 - Ebola haemorrhagic fever in Gabon/The Republic of the Congo - Update 20$"), "Country"] <- c("Congo", "Gabon")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2002 - Ebola haemorrhagic fever in Gabon/The Republic of the Congo - Update 16$"), "Country"] <- c("Congo", "Gabon")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2002 - Ebola haemorrhagic fever in Gabon/The Republic of the Congo - Update 15$"), "Country"] <- c("Congo", "Gabon")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2002 - Ebola haemorrhagic fever in Gabon/The Republic of the Congo - Update 14$"), "Country"] <- c("Congo", "Gabon")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^2002 - Ebola haemorrhagic fever in Gabon/The Republic of the Congo Update 13$"), "Country"] <- c("Congo", "Gabon")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Zika virus infection – Brazil and Colombia$"), "Country"] <- c("Brazil", "Colombia") 
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Poliomyelitis in West Africa: Togo, Burkina Faso and Ghana$"), "Country"] <- c("Togo", "Burkina Faso", "Ghana") 
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Botulism in the United States and Canada$"), "Country"] <- c("Canada", "United States of America")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^EHEC outbreak: Increase in cases in Germany$"), "Country"] <- c("Germany", "Austria", "Denmark", "France", "Netherlands", "Norway", "Sweden", "Switzerland", "United Kingdom of Great Britain and Northern Ireland")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Cholera in Central Africa$"), "Country"] <- c("Cameroon", "Chad", "Niger", "Nigeria")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Cholera in Chad, Mozambique and Zambia$"), "Country"] <- c("Chad", "Mozambique", "Zambia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Avian influenza A(H5N1) - update 28: Reports of infection in domestic cats (Thailand), Situation (human) in Thailand, Situation (poultry) in Japan and China$"), "Country"] <- c("Thailand", "Japan", "China")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Zika virus infection – Dominica and Cuba$"), "Country"] <- c("Dominica", "Cuba")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Avian influenza A(H5N1) - update 21:Global surveillance guidelines, Investigation of possible human-to-human transmission: data on second sister in family cluster in Viet Nam$"), "Country"] <- c("Viet Nam", "China")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Zika virus infection – Guyana, Barbados and Ecuador$"), "Country"] <- c("Guyana", "Barbados", "Ecuador")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Avian influenza – situation in Thailand, Indonesia – update 36$"), "Country"] <- c("Thailand", "Indonesia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1996 - Dengue/dengue haemorrhagic fever in Malaysia and Indonesia$"), "Country"] <- c("Malaysia", "Indonesia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1996 - Diphtheria in Laos and Thailand$"), "Country"] <- c("Thailand", "Lao People's Democratic Republic")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1999 - Hendra-like virus in Malaysia and Singapore$"), "Country"] <- c("Malaysia", "Singapore")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Influenza-like illness in the United States and Mexico$"), "Country"] <- c("Mexico", "United States of America")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Swine flu illness in the United States and Mexico - update 2$"), "Country"] <- c("Mexico", "United States of America")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^New virus from Arenaviridae family in South Africa and Zambia - Update$"), "Country"] <- c("South Africa", "Zambia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Unknown disease in South Africa and Zambia$"), "Country"] <- c("South Africa", "Zambia")
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^Middle East respiratory syndrome coronavirus \\(MERS-CoV\\) – Bahrain$"), "Country"] <- "Bahrain"
DONsdf9[grepl(DONsdf9$Outbreak, pattern = "^1996 - Bovine Spongiform Encephalopathy (BSE)$"), "Country"] <- "United Kingdom of Great Britain and Northern Ireland"

# Only DONs related to diseases and associated to a specific country and period, i.e. deleting those with information on events, rules, recommendations, etc.
DONsdf10 <- DONsdf9 %>%
  drop_na(Country)

#### Editing the code for Namibia
iso[grepl(pattern = "Namibia", iso$Country), "iso2"] <- "NA"

### Joining the dataset with the iso contry names ###
DONsdf11 <- merge(DONsdf10, iso, by = "Country", all.x = TRUE)

DONsdf11$key <- paste0(DONsdf11$iso3, DONsdf11$Year, DONsdf11$icd104c) # to identify all the DONs for each outbreak
DONsdf11$key <- as.factor(DONsdf11$key)

DONsdf11$DONs <- NA
for(don in levels(DONsdf11$key)){
  dons <- paste(DONsdf11[DONsdf11$key == don, "ID"], sep = ", ")
  dons <- paste(unlist(dons), collapse = ", ")
  DONsdf11[DONsdf11$key == don, "DONs"] <- dons
}

#### Unique cases per country per year ####
DONsdf12 <- unique(DONsdf11[, c("Country", "iso2", "iso3", "Year", "icd10n", "icd103n", "icd104n", "icd10c", "icd103c", "icd104c", "icd11c1", "icd11c2", "icd11c3", "icd11l1", "icd11l2", "icd11l3", "Disease", "DONs", "Definition")]) # 1566 unique events 

AllDONs <- DONsdf11[, c("Country", "iso2", "iso3", "Year", "icd10n", "icd103n", "icd104n", "icd10c", "icd103c", "icd104c", "icd11c1", "icd11c2", "icd11c3", "icd11l1", "icd11l2", "icd11l3", "Disease", "DONs", "Definition")]
UniqueDONs <- DONsdf12

save(AllDONs, file = "AllDONs.RData")
save(UniqueDONs, file = "UniqueDONs.RData")

#### Corona Dashboard ####
coronaOut <- read.csv("WHO-COVID-19-global-data.csv")

coronaOut <- coronaOut %>%
  mutate(Year = substr(Date_reported, 1, 4))

coronaOut <- coronaOut %>%
  filter(Date_reported < "2022-04-01") %>%
  aggregate(New_cases ~ Country_code + Country + Year, sum) 

coronaOut <- coronaOut %>%
  filter(New_cases > 0)

coronaOut <- coronaOut %>%
  mutate(icd10n = "Provisional assignment of new diseases of uncertain etiology or emergency use") %>% 
  mutate(icd103n = "Emergency use of U07") %>% 
  mutate(icd104n = "COVID-19, virus identified") %>% 
  mutate(icd10c = "U00-U49") %>% 
  mutate(icd103c = "U07") %>% 
  mutate(icd104c = "U071") %>% 
  mutate(icd11c1 = "25") %>% 
  mutate(icd11c2 = "RA01") %>% 
  mutate(icd11c3 = "25RA01") %>% 
  mutate(icd11l1 = "Codes for special purposes") %>% 
  mutate(icd11l2 = "International provisional assignment of new diseases of uncertain aetiology and emergency use") %>% 
  mutate(icd11l3 = "COVID-19") %>% 
  mutate(Disease = "COVID-19") %>% 
  mutate(DONs = "Coronavirus dashboard") %>% 
  mutate(Definition = "Infectious disease caused by the SARS-CoV-2 virus.") %>%
  mutate(iso2 = Country_code)

coronaOut <- merge(coronaOut[, c("iso2", "Year", "icd10n", "icd103n", "icd104n", "icd10c", "icd103c", "icd104c", "icd11c1", "icd11c2", "icd11c3", "icd11l1", "icd11l2", "icd11l3", "Disease", "DONs", "Definition")], 
                   iso, by = "iso2", all.x = TRUE)

## Bonaire Sint Eustatius and Saba together in the iso 
coronaOut[!is.na(coronaOut$iso2) & coronaOut$iso2 == "XA", "Country"] <- "Bonaire Sint Eustatius and Saba"
coronaOut[!is.na(coronaOut$iso2) & coronaOut$iso2 == "XB", "Country"] <- "Bonaire Sint Eustatius and Saba"
coronaOut[!is.na(coronaOut$iso2) & coronaOut$iso2 == "XC", "Country"] <- "Bonaire Sint Eustatius and Saba"
coronaOut[!is.na(coronaOut$iso2) & coronaOut$iso2 == "XA", "iso2"] <- "BQ"
coronaOut[!is.na(coronaOut$iso2) & coronaOut$iso2 == "XB", "iso2"] <- "BQ"
coronaOut[!is.na(coronaOut$iso2) & coronaOut$iso2 == "XC", "iso2"] <- "BQ"
coronaOut[!is.na(coronaOut$iso2) & coronaOut$iso2 == "XA", "iso2"] <- "BES"
coronaOut[!is.na(coronaOut$iso2) & coronaOut$iso2 == "XB", "iso2"] <- "BES"
coronaOut[!is.na(coronaOut$iso2) & coronaOut$iso2 == "XC", "iso2"] <- "BES"

COVIDOutbreaks <- coronaOut[, colnames(DONsdf12)]

COVIDOutbreaks <- COVIDOutbreaks[!is.na(COVIDOutbreaks$Country), ]
COVIDOutbreaks[!is.na(COVIDOutbreaks$iso2) & COVIDOutbreaks$iso2 == "BQ", "Country"] <- "Bonaire Sint Eustatius and Saba"
COVIDOutbreaks[!is.na(COVIDOutbreaks$iso2) & COVIDOutbreaks$iso2 == "BQ", "iso2"] <- "BQ"
COVIDOutbreaks[!is.na(COVIDOutbreaks$iso2) & COVIDOutbreaks$iso2 == "BQ", "iso3"] <- "BES"

save(COVIDOutbreaks, file = "COVIDOutbreaks.RData") # 665 cases

levels(factor(COVIDOutbreaks$Country)) # Number of countries: 224
levels(factor(COVIDOutbreaks$icd104n)) # Only one disease: COVID-19, virus identified

#### Final dataset of outbreaks ####
Outbreaks <- rbind(DONsdf12, COVIDOutbreaks) # 1562 + 665
rownames(Outbreaks) <- 1:nrow(Outbreaks)
Outbreaks[!is.na(Outbreaks$iso2) & Outbreaks$iso2 == "BQ", "Country"] <- "Bonaire Sint Eustatius and Saba"
Outbreaks[!is.na(Outbreaks$iso2) & Outbreaks$iso2 == "BQ", "iso2"] <- "BQ"
Outbreaks[!is.na(Outbreaks$iso2) & Outbreaks$iso2 == "BQ", "iso3"] <- "BES"

Outbreaks[!is.na(Outbreaks$Country) & Outbreaks$Country == "Kosovo", "iso2"] <- "XK"
Outbreaks[!is.na(Outbreaks$iso2) & Outbreaks$iso2 == "XK", "Country"] <- "Kosovo"
Outbreaks[!is.na(Outbreaks$iso2) & Outbreaks$iso2 == "XK", "iso3"] <- "XXK"

Outbreaks[!is.na(Outbreaks$Country) & Outbreaks$Country == "Gaza", "iso2"] <- "PS"
Outbreaks[!is.na(Outbreaks$Country) & Outbreaks$Country == "Gaza", "Country"] <- "Palestine State of"
Outbreaks[!is.na(Outbreaks$Country) & Outbreaks$Country == "Palestine State of", "iso3"] <- "PSE"

Outbreaks <- Outbreaks[!is.na(Outbreaks$Country), ] # 2227

levels(factor(Outbreaks$Country)) # Number of countries: 233
levels(factor(Outbreaks$icd104n)) # Number of disease: 70

save(Outbreaks, file = "Outbreaks.RData")

